<?php
/**
 * Do not remove these lines, sky will fall on your head.
 */
define( 'MTS_THEME_NAME', 'wooshop' );
define( 'MTS_THEME_VERSION', '1.2.4' );

require_once( get_theme_file_path( 'theme-options.php' ) );
if ( ! isset( $content_width ) ) {
	$content_width = 660; //article content width without padding
}

/**
 *	Load Options
 */
$mts_options = get_option( MTS_THEME_NAME );

/**
 * Register supported theme features, image sizes and nav menus.
 * Also loads translated strings.
 */
function mts_after_setup_theme() {
	if ( ! defined( 'MTS_THEME_WHITE_LABEL' ) ) {
		define( 'MTS_THEME_WHITE_LABEL', false );
	}

	add_theme_support( 'title-tag' );
	add_theme_support( 'automatic-feed-links' );

	load_theme_textdomain( 'wooshop', get_template_directory().'/lang' );

	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 320, 190, true );
	add_image_size( 'wooshop-blogpost', 320, 190, true ); //blog page
	add_image_size( 'wooshop-blogslider', 660, 300, true ); //blog slider
	add_image_size( 'wooshop-widgetthumb', 80, 80, true ); //widget
	add_image_size( 'wooshop-widgetfull', 250, 180, true ); //sidebar full width
	add_image_size( 'wooshop-slider', 796, 350, true ); //slider
	add_image_size( 'wooshop-size-chart', 400 );
	add_image_size( 'wooshop-size-chart-full', 800 );

	register_nav_menus( array(
	  'primary-menu' => __( 'Primary', 'wooshop' ),
	  'footer-menu' => __( 'Footer', 'wooshop' ),
	  'mobile' => __( 'Mobile', 'wooshop' )
	) );

	if ( mts_is_wc_active() ) {
		add_theme_support( 'woocommerce' );
		$mts_options = get_option( MTS_THEME_NAME );
		if ( '1' !== $mts_options['mts_single_product_slider'] ) {
			add_theme_support( 'wc-product-gallery-zoom' );
			add_theme_support( 'wc-product-gallery-lightbox' );
			add_theme_support( 'wc-product-gallery-slider' );
		}
	}
}
add_action('after_setup_theme', 'mts_after_setup_theme' );

/**
 * Disable auto-updating the theme.
 */
function mts_disable_auto_update_theme( $update, $item ) {
	if ( $item->slug == MTS_THEME_NAME ) {
		return false;
	}
	return $update;
}
add_filter( 'auto_update_theme', 'mts_disable_auto_update_theme', 10, 2 );

/**
 * Disable Google Typography plugin
 */
function mts_deactivate_google_typography_plugin() {
	if ( in_array( 'google-typography/google-typography.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
		deactivate_plugins( 'google-typography/google-typography.php' );
	}
}
add_action( 'admin_init', 'mts_deactivate_google_typography_plugin' );

/**
 * Determines whether the WooCommerce plugin is active or not.
 * @return bool
 */
function mts_is_wc_active() {
	return class_exists( 'WooCommerce' );
}

/**
 *  Post Formats
 */
add_theme_support( 'post-formats', array( 'gallery', 'video', 'audio', 'quote' ) );

/**
 * MTS icons for use in nav menus and icon select option.
 *
 * @return array
 */
function mts_get_icons() {
	$icons = array(
		__( 'Web Application Icons', 'wooshop' ) => array(
			'address-book', 'address-book-o', 'address-card', 'address-card-o', 'adjust', 'american-sign-language-interpreting', 'anchor', 'archive', 'area-chart', 'arrows', 'arrows-h', 'arrows-v', 'asl-interpreting', 'assistive-listening-systems', 'asterisk', 'at', 'audio-description', 'automobile', 'balance-scale', 'ban', 'bank', 'bar-chart', 'bar-chart-o', 'barcode', 'bars', 'bath', 'bathtub', 'battery', 'battery-0', 'battery-1', 'battery-2', 'battery-3', 'battery-4', 'battery-empty', 'battery-full', 'battery-half', 'battery-quarter', 'battery-three-quarters', 'bed', 'beer', 'bell', 'bell-o', 'bell-slash', 'bell-slash-o', 'bicycle', 'binoculars', 'birthday-cake', 'blind', 'bluetooth', 'bluetooth-b', 'bolt', 'bomb', 'book', 'bookmark', 'bookmark-o', 'braille', 'briefcase', 'bug', 'building', 'building-o', 'bullhorn', 'bullseye', 'bus', 'cab', 'calculator', 'calendar', 'calendar-check-o', 'calendar-minus-o', 'calendar-o', 'calendar-plus-o', 'calendar-times-o', 'camera', 'camera-retro', 'car', 'caret-square-o-down', 'caret-square-o-left', 'caret-square-o-right', 'caret-square-o-up', 'cart-arrow-down', 'cart-plus', 'cc', 'certificate', 'check', 'check-circle', 'check-circle-o', 'check-square', 'check-square-o', 'child', 'circle', 'circle-o', 'circle-o-notch', 'circle-thin', 'clock-o', 'clone', 'close', 'cloud', 'cloud-download', 'cloud-upload', 'code', 'code-fork', 'coffee', 'cog', 'cogs', 'comment', 'comment-o', 'commenting', 'commenting-o', 'comments', 'comments-o', 'compass', 'copyright', 'creative-commons', 'credit-card', 'credit-card-alt', 'crop', 'crosshairs', 'cube', 'cubes', 'cutlery', 'dashboard', 'database', 'deaf', 'deafness', 'desktop', 'diamond', 'dot-circle-o', 'download', 'drivers-license', 'drivers-license-o', 'edit', 'ellipsis-h', 'ellipsis-v', 'envelope', 'envelope-o', 'envelope-open', 'envelope-open-o', 'envelope-square', 'eraser', 'exchange', 'exclamation', 'exclamation-circle', 'exclamation-triangle', 'external-link', 'external-link-square', 'eye', 'eye-slash', 'eyedropper', 'fax', 'feed', 'female', 'fighter-jet', 'file-archive-o', 'file-audio-o', 'file-code-o', 'file-excel-o', 'file-image-o', 'file-movie-o', 'file-pdf-o', 'file-photo-o', 'file-picture-o', 'file-powerpoint-o', 'file-sound-o', 'file-video-o', 'file-word-o', 'file-zip-o', 'film', 'filter', 'fire', 'fire-extinguisher', 'flag', 'flag-checkered', 'flag-o', 'flash', 'flask', 'folder', 'folder-o', 'folder-open', 'folder-open-o', 'frown-o', 'futbol-o', 'gamepad', 'gavel', 'gear', 'gears', 'gift', 'glass', 'globe', 'graduation-cap', 'group', 'hand-grab-o', 'hand-lizard-o', 'hand-paper-o', 'hand-peace-o', 'hand-pointer-o', 'hand-rock-o', 'hand-scissors-o', 'hand-spock-o', 'hand-stop-o', 'handshake-o', 'hard-of-hearing', 'hashtag', 'hdd-o', 'headphones', 'heart', 'heart-o', 'heartbeat', 'history', 'home', 'hotel', 'hourglass', 'hourglass-1', 'hourglass-2', 'hourglass-3', 'hourglass-end', 'hourglass-half', 'hourglass-o', 'hourglass-start', 'i-cursor', 'id-badge', 'id-card', 'id-card-o', 'image', 'inbox', 'industry', 'info', 'info-circle', 'institution', 'key', 'keyboard-o', 'language', 'laptop', 'leaf', 'legal', 'lemon-o', 'level-down', 'level-up', 'life-bouy', 'life-buoy', 'life-ring', 'life-saver', 'lightbulb-o', 'line-chart', 'location-arrow', 'lock', 'low-vision', 'magic', 'magnet', 'mail-forward', 'mail-reply', 'mail-reply-all', 'male', 'map', 'map-marker', 'map-o', 'map-pin', 'map-signs', 'meh-o', 'microchip', 'microphone', 'microphone-slash', 'minus', 'minus-circle', 'minus-square', 'minus-square-o', 'mobile', 'mobile-phone', 'money', 'moon-o', 'mortar-board', 'motorcycle', 'mouse-pointer', 'music', 'navicon', 'newspaper-o', 'object-group', 'object-ungroup', 'paint-brush', 'paper-plane', 'paper-plane-o', 'paw', 'pencil', 'pencil-square', 'pencil-square-o', 'percent', 'phone', 'phone-square', 'photo', 'picture-o', 'pie-chart', 'plane', 'plug', 'plus', 'plus-circle', 'plus-square', 'plus-square-o', 'podcast', 'power-off', 'print', 'puzzle-piece', 'qrcode', 'question', 'question-circle', 'question-circle-o', 'quote-left', 'quote-right', 'random', 'recycle', 'refresh', 'registered', 'remove', 'reorder', 'reply', 'reply-all', 'retweet', 'road', 'rocket', 'rss', 'rss-square', 's15', 'search', 'search-minus', 'search-plus', 'send', 'send-o', 'server', 'share', 'share-alt', 'share-alt-square', 'share-square', 'share-square-o', 'shield', 'ship', 'shopping-bag', 'shopping-basket', 'shopping-cart', 'shower', 'sign-in', 'sign-language', 'sign-out', 'signal', 'signing', 'sitemap', 'sliders', 'smile-o', 'snowflake-o', 'soccer-ball-o', 'sort', 'sort-alpha-asc', 'sort-alpha-desc', 'sort-amount-asc', 'sort-amount-desc', 'sort-asc', 'sort-desc', 'sort-down', 'sort-numeric-asc', 'sort-numeric-desc', 'sort-up', 'space-shuttle', 'spinner', 'spoon', 'square', 'square-o', 'star', 'star-half', 'star-half-empty', 'star-half-full', 'star-half-o', 'star-o', 'sticky-note', 'sticky-note-o', 'street-view', 'suitcase', 'sun-o', 'support', 'tablet', 'tachometer', 'tag', 'tags', 'tasks', 'taxi', 'television', 'terminal', 'thermometer', 'thermometer-0', 'thermometer-1', 'thermometer-2', 'thermometer-3', 'thermometer-4', 'thermometer-empty', 'thermometer-full', 'thermometer-half', 'thermometer-quarter', 'thermometer-three-quarters', 'thumb-tack', 'thumbs-down', 'thumbs-o-down', 'thumbs-o-up', 'thumbs-up', 'ticket', 'times', 'times-circle', 'times-circle-o', 'times-rectangle', 'times-rectangle-o', 'tint', 'toggle-down', 'toggle-left', 'toggle-off', 'toggle-on', 'toggle-right', 'toggle-up', 'trademark', 'trash', 'trash-o', 'tree', 'trophy', 'truck', 'tty', 'tv', 'umbrella', 'universal-access', 'university', 'unlock', 'unlock-alt', 'unsorted', 'upload', 'user', 'user-circle', 'user-circle-o', 'user-o', 'user-plus', 'user-secret', 'user-times', 'users', 'vcard', 'vcard-o', 'video-camera', 'volume-control-phone', 'volume-down', 'volume-off', 'volume-up', 'warning', 'wheelchair', 'wheelchair-alt', 'wifi', 'window-close', 'window-close-o', 'window-maximize', 'window-minimize', 'window-restore', 'wrench'
		),
		__( 'Accessibility Icons', 'wooshop' ) => array(
			'american-sign-language-interpreting', 'asl-interpreting', 'assistive-listening-systems', 'audio-description', 'blind', 'braille', 'cc', 'deaf', 'deafness', 'hard-of-hearing', 'low-vision', 'question-circle-o', 'sign-language', 'signing', 'tty', 'universal-access', 'volume-control-phone', 'wheelchair', 'wheelchair-alt'
		),
		__( 'Hand Icons', 'wooshop' ) => array(
			'hand-grab-o', 'hand-lizard-o', 'hand-o-down', 'hand-o-left', 'hand-o-right', 'hand-o-up', 'hand-paper-o', 'hand-peace-o', 'hand-pointer-o', 'hand-rock-o', 'hand-scissors-o', 'hand-spock-o', 'hand-stop-o', 'thumbs-down', 'thumbs-o-down', 'thumbs-o-up', 'thumbs-up'
		),
		__( 'Transportation Icons', 'wooshop' ) => array(
			'ambulance', 'automobile', 'bicycle', 'bus', 'cab', 'car', 'fighter-jet', 'motorcycle', 'plane', 'rocket', 'ship', 'space-shuttle', 'subway', 'taxi', 'train', 'truck', 'wheelchair', 'wheelchair-alt'
		),
		__( 'Gender Icons', 'wooshop' ) => array(
			'genderless', 'intersex', 'mars', 'mars-double', 'mars-stroke', 'mars-stroke-h', 'mars-stroke-v', 'mercury', 'neuter', 'transgender', 'transgender-alt', 'venus', 'venus-double', 'venus-mars'
		),
		__( 'File Type Icons', 'wooshop' ) => array(
			'file', 'file-archive-o', 'file-audio-o', 'file-code-o', 'file-excel-o', 'file-image-o', 'file-movie-o', 'file-o', 'file-pdf-o', 'file-photo-o', 'file-picture-o', 'file-powerpoint-o', 'file-sound-o', 'file-text', 'file-text-o', 'file-video-o', 'file-word-o', 'file-zip-o'
		),
		__( 'Spinner Icons', 'wooshop' ) => array(
			'circle-o-notch', 'cog', 'gear', 'refresh', 'spinner'
		),
		__( 'Form Control Icons', 'wooshop' ) => array(
			'check-square', 'check-square-o', 'circle', 'circle-o', 'dot-circle-o', 'minus-square', 'minus-square-o', 'plus-square', 'plus-square-o', 'square', 'square-o'
		),
		__( 'Payment Icons', 'wooshop' ) => array(
			'cc-amex', 'cc-diners-club', 'cc-discover', 'cc-jcb', 'cc-mastercard', 'cc-paypal', 'cc-stripe', 'cc-visa', 'credit-card', 'credit-card-alt', 'google-wallet', 'paypal'
		),
		__( 'Chart Icons', 'wooshop' ) => array(
			'area-chart', 'bar-chart', 'bar-chart-o', 'line-chart', 'pie-chart'
		),
		__( 'Currency Icons', 'wooshop' ) => array(
			'bitcoin', 'btc', 'cny', 'dollar', 'eur', 'euro', 'gbp', 'gg', 'gg-circle', 'ils', 'inr', 'jpy', 'krw', 'money', 'rmb', 'rouble', 'rub', 'ruble', 'rupee', 'shekel', 'sheqel', 'try', 'turkish-lira', 'usd', 'won', 'yen'
		),
		__( 'Text Editor Icons', 'wooshop' ) => array(
			'align-center', 'align-justify', 'align-left', 'align-right', 'bold', 'chain', 'chain-broken', 'clipboard', 'columns', 'copy', 'cut', 'dedent', 'eraser', 'file', 'file-o', 'file-text', 'file-text-o', 'files-o', 'floppy-o', 'font', 'header', 'indent', 'italic', 'link', 'list', 'list-alt', 'list-ol', 'list-ul', 'outdent', 'paperclip', 'paragraph', 'paste', 'repeat', 'rotate-left', 'rotate-right', 'save', 'scissors', 'strikethrough', 'subscript', 'superscript', 'table', 'text-height', 'text-width', 'th', 'th-large', 'th-list', 'underline', 'undo', 'unlink'
		),
		__( 'Directional Icons', 'wooshop' ) => array(
			'angle-double-down', 'angle-double-left', 'angle-double-right', 'angle-double-up', 'angle-down', 'angle-left', 'angle-right', 'angle-up', 'arrow-circle-down', 'arrow-circle-left', 'arrow-circle-o-down', 'arrow-circle-o-left', 'arrow-circle-o-right', 'arrow-circle-o-up', 'arrow-circle-right', 'arrow-circle-up', 'arrow-down', 'arrow-left', 'arrow-right', 'arrow-up', 'arrows', 'arrows-alt', 'arrows-h', 'arrows-v', 'caret-down', 'caret-left', 'caret-right', 'caret-square-o-down', 'caret-square-o-left', 'caret-square-o-right', 'caret-square-o-up', 'caret-up', 'chevron-circle-down', 'chevron-circle-left', 'chevron-circle-right', 'chevron-circle-up', 'chevron-down', 'chevron-left', 'chevron-right', 'chevron-up', 'exchange', 'hand-o-down', 'hand-o-left', 'hand-o-right', 'hand-o-up', 'long-arrow-down', 'long-arrow-left', 'long-arrow-right', 'long-arrow-up', 'toggle-down', 'toggle-left', 'toggle-right', 'toggle-up'
		),
		__( 'Video Player Icons', 'wooshop' ) => array(
			'arrows-alt', 'backward', 'compress', 'eject', 'expand', 'fast-backward', 'fast-forward', 'forward', 'pause', 'pause-circle', 'pause-circle-o', 'play', 'play-circle', 'play-circle-o', 'random', 'step-backward', 'step-forward', 'stop', 'stop-circle', 'stop-circle-o', 'youtube-play'
		),
		__( 'Brand Icons', 'wooshop' ) => array(
			'500px', 'adn', 'amazon', 'android', 'angellist', 'apple', 'bandcamp', 'behance', 'behance-square', 'bitbucket', 'bitbucket-square', 'bitcoin', 'black-tie', 'bluetooth', 'bluetooth-b', 'btc', 'buysellads', 'cc-amex', 'cc-diners-club', 'cc-discover', 'cc-jcb', 'cc-mastercard', 'cc-paypal', 'cc-stripe', 'cc-visa', 'chrome', 'codepen', 'codiepie', 'connectdevelop', 'contao', 'css3', 'dashcube', 'delicious', 'deviantart', 'digg', 'dribbble', 'dropbox', 'drupal', 'edge', 'eercast', 'empire', 'envira', 'etsy', 'expeditedssl', 'fa', 'facebook', 'facebook-f', 'facebook-official', 'facebook-square', 'firefox', 'first-order', 'flickr', 'font-awesome', 'fonticons', 'fort-awesome', 'forumbee', 'foursquare', 'free-code-camp', 'ge', 'get-pocket', 'gg', 'gg-circle', 'git', 'git-square', 'github', 'github-alt', 'github-square', 'gitlab', 'gittip', 'glide', 'glide-g', 'google', 'google-plus', 'google-plus-circle', 'google-plus-official', 'google-plus-square', 'google-wallet', 'gratipay', 'grav', 'hacker-news', 'houzz', 'html5', 'imdb', 'instagram', 'internet-explorer', 'ioxhost', 'joomla', 'jsfiddle', 'lastfm', 'lastfm-square', 'leanpub', 'linkedin', 'linkedin-square', 'linode', 'linux', 'maxcdn', 'meanpath', 'medium', 'meetup', 'mixcloud', 'modx', 'odnoklassniki', 'odnoklassniki-square', 'opencart', 'openid', 'opera', 'optin-monster', 'pagelines', 'paypal', 'pied-piper', 'pied-piper-alt', 'pied-piper-pp', 'pinterest', 'pinterest-p', 'pinterest-square', 'product-hunt', 'qq', 'quora', 'ra', 'ravelry', 'rebel', 'reddit', 'reddit-alien', 'reddit-square', 'renren', 'resistance', 'safari', 'scribd', 'sellsy', 'share-alt', 'share-alt-square', 'shirtsinbulk', 'simplybuilt', 'skyatlas', 'skype', 'slack', 'slideshare', 'snapchat', 'snapchat-ghost', 'snapchat-square', 'soundcloud', 'spotify', 'stack-exchange', 'stack-overflow', 'steam', 'steam-square', 'stumbleupon', 'stumbleupon-circle', 'superpowers', 'telegram', 'tencent-weibo', 'themeisle', 'trello', 'tripadvisor', 'tumblr', 'tumblr-square', 'twitch', 'twitter', 'twitter-square', 'usb', 'viacoin', 'viadeo', 'viadeo-square', 'vimeo', 'vimeo-square', 'vine', 'vk', 'wechat', 'weibo', 'weixin', 'whatsapp', 'wikipedia-w', 'windows', 'wordpress', 'wpbeginner', 'wpexplorer', 'wpforms', 'xing', 'xing-square', 'y-combinator', 'y-combinator-square', 'yahoo', 'yc', 'yc-square', 'yelp', 'yoast', 'youtube', 'youtube-play', 'youtube-square'
		),
		__( 'Medical Icons', 'wooshop' ) => array(
			'ambulance', 'h-square', 'heart', 'heart-o', 'heartbeat', 'hospital-o', 'medkit', 'plus-square', 'stethoscope', 'user-md', 'wheelchair', 'wheelchair-alt'
		)
	);

	return $icons;
}

/**
 * Create pages on Theme Activation
 */
if ( isset( $_GET['activated'] ) && is_admin() ) {
	$pages_to_add = array(
		array(
			'post_type' => 'page',
			'post_title' => __('Wishlist', 'wooshop'),
			'post_content' => '',
			'page_template' => 'page-wishlist.php',
			'post_status' => 'publish',
			'post_author' => 1,
		)
	);
	foreach ( $pages_to_add as $page_settings ) {
		$page_check = get_page_by_title( $page_settings['post_title'] );
		if ( !isset( $page_check->ID ) ) {
			$new_page_id = wp_insert_post( $page_settings );
			if ( !empty( $page_settings['page_template'] ) ) {
				update_post_meta( $new_page_id, '_wp_page_template', $page_settings['page_template'] );
			}
			$page_id = $new_page_id;
		} else {
			$page_id = $page_check->ID;
		}
	}
}


/**
 * Get the current post's thumbnail URL.
 *
 * @param string $size
 *
 * @return string
 */
if( !function_exists('mts_get_thumbnail_url') ) {
	function mts_get_thumbnail_url( $size = 'full' ) {
		$post_id = get_the_ID() ;
		if (has_post_thumbnail( $post_id ) ) {
			$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), $size );
			return $image[0];
		}

		// use first attached image
		$images = get_children( 'post_type=attachment&post_mime_type=image&post_parent=' . $post_id );
		if (!empty($images)) {
			$image = reset($images);
			$image_data = wp_get_attachment_image_src( $image->ID, $size );
			return $image_data[0];
		}

		// use no preview fallback
		if ( file_exists( get_template_directory().'/images/nothumb-'.$size.'.png' ) ) {
			return get_template_directory_uri().'/images/nothumb-'.$size.'.png';
		}

		return '';
	}
}
/**
 * Create and show column for featured in portfolio items list admin page.
 * @param $post_ID
 *
 * @return string url
 */
if( !function_exists('mts_get_featured_image')){
	function mts_get_featured_image($post_ID) {
		$post_thumbnail_id = get_post_thumbnail_id($post_ID);
		if ($post_thumbnail_id) {
			$post_thumbnail_img = wp_get_attachment_image_src($post_thumbnail_id, 'wooshop-widgetthumb');
			return $post_thumbnail_img[0];
		}
	}
}
/**
 * Adds a `Featured Image` column header in the item list admin page.
 *
 * @param array $defaults
 *
 * @return array
 */
function mts_columns_head($defaults) {
	if (get_post_type() == 'post') {
		$defaults['featured_image'] = __('Featured Image', 'wooshop' );
	}

	return $defaults;
}
add_filter('manage_posts_columns', 'mts_columns_head');

/**
 * Adds a `Featured Image` column row value in the item list admin page.
 *
 * @param string $column_name The name of the column to display.
 * @param int $post_ID The ID of the current post.
 */
function mts_columns_content($column_name, $post_ID) {
	if ($column_name == 'featured_image') {
		$post_featured_image = mts_get_featured_image($post_ID);
		if ($post_featured_image) {
			echo '<img width="80" height="80" src="' . esc_url( $post_featured_image ) . '" />';
		}
	}
}
add_action('manage_posts_custom_column', 'mts_columns_content', 10, 2);

/**
 * Admin styles
 */
function mts_columns_css() {
	echo '<style type="text/css">.posts .column-featured_image img { max-width: 100%; height: auto }</style>';
}
add_action( 'admin_print_styles', 'mts_columns_css' );

/**
 * Change the HTML markup of the post thumbnail.
 *
 * @param string $html
 * @param int $post_id
 * @param string $post_image_id
 * @param int $size
 * @param string $attr
 *
 * @return string
 */
function mts_post_image_html( $html, $post_id, $post_image_id, $size, $attr ) {
	if ( has_post_thumbnail( $post_id ) || 'shop_thumbnail' === $size )
		return $html;

	// use first attached image
	$images = get_children( 'post_type=attachment&post_mime_type=image&post_parent=' . $post_id );
	if (!empty($images)) {
		$image = reset($images);
		return wp_get_attachment_image( $image->ID, $size, false, $attr );
	}

	// use no preview fallback
	if ( file_exists( get_template_directory().'/images/nothumb-'.$size.'.png' ) ) {
		$placeholder = get_template_directory_uri().'/images/nothumb-'.$size.'.png';
		$mts_options = get_option( MTS_THEME_NAME );
		if ( ! empty( $mts_options['mts_lazy_load'] ) && ! empty( $mts_options['mts_lazy_load_thumbs'] ) ) {
			$placeholder_src = '';
			$layzr_attr = ' data-layzr="'.esc_attr( $placeholder ).'"';
		} else {
			$placeholder_src = $placeholder;
			$layzr_attr = '';
		}

		$placeholder_classs = 'attachment-'.$size.' wp-post-image';
		return '<img src="'.esc_url( $placeholder_src ).'" class="'.esc_attr( $placeholder_classs ).'" alt="'.esc_attr( get_the_title() ).'"'.$layzr_attr.'>';
	}

	return '';
}
add_filter( 'post_thumbnail_html', 'mts_post_image_html', 10, 5 );

/**
 * Add data-layzr attribute to featured image ( for lazy load )
 *
 * @param array $attr
 * @param WP_Post $attachment
 * @param string|array $size
 *
 * @return array
 */
function mts_image_lazy_load_attr( $attr, $attachment, $size ) {
	if ( is_admin() || is_feed() ) return $attr;
	if ( is_single() && function_exists( 'is_amp_endpoint' ) && is_amp_endpoint() ) return $attr;
	$mts_options = get_option( MTS_THEME_NAME );
	if ( ! empty( $mts_options['mts_lazy_load'] ) && ! empty( $mts_options['mts_lazy_load_thumbs'] ) ) {
		$attr['data-layzr'] = $attr['src'];
		$attr['src'] = '';
		if ( isset( $attr['srcset'] ) ) {
			$attr['data-layzr-srcset'] = $attr['srcset'];
			$attr['srcset'] = '';
		}
	}

	return $attr;
}
add_filter( 'wp_get_attachment_image_attributes', 'mts_image_lazy_load_attr', 10, 3 );

/**
 * Add data-layzr attribute to post content images ( for lazy load )
 *
 * @param string $content
 *
 * @return string
 */

function mts_content_image_lazy_load_attr( $content ) {
	$mts_options = get_option( MTS_THEME_NAME );
	if ( is_single() && function_exists( 'is_amp_endpoint' ) && is_amp_endpoint() ) {
		return $content;
	}
	if ( ! empty( $mts_options['mts_lazy_load'] )
		 && ! empty( $mts_options['mts_lazy_load_content'] )
		 && ! empty( $content ) ) {
		$content = preg_replace_callback(
			'/<img([^>]+?)src=[\'"]?([^\'"\s>]+)[\'"]?([^>]*)>/',
			'mts_content_image_lazy_load_attr_callback',
			$content
		);
	}

	return $content;
}
add_filter('the_content', 'mts_content_image_lazy_load_attr');

/**
 * Callback to move src to data-src and replace it with a 1x1 transparent image.
 *
 * @param $matches
 *
 * @return string
 */
function mts_content_image_lazy_load_attr_callback( $matches ) {
	$transparent_img = 'data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==';
	if ( preg_match( '/ data-lazy *= *"false" */', $matches[0] ) ) {
		return '<img' . $matches[1] . 'src="' . $matches[2] . '"' . $matches[3] . '>';
	} else {
		return '<img' . $matches[1] . 'src="' . $transparent_img . '" data-layzr="' . $matches[2] . '"' . str_replace( 'srcset=', 'data-layzr-srcset=', $matches[3]). '>';
	}
}

/**
 * Enable Widgetized sidebar and Footer
 */
function mts_register_sidebars() {
	$mts_options = get_option( MTS_THEME_NAME );

	// Homepage sidebar
	register_sidebar( array(
		'name' => __('Homepage Sidebar', 'wooshop'),
		'description'   => __( 'Homepage sidebar.', 'wooshop' ),
		'id' => 'homepage-sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Default sidebar
	register_sidebar( array(
		'name' => __('Sidebar', 'wooshop'),
		'description'   => __( 'Default sidebar.', 'wooshop' ),
		'id' => 'sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Top level footer widget areas
	if ( !empty( $mts_options['mts_first_footer'] )) {
		if ( empty( $mts_options['mts_first_footer_num'] )) $mts_options['mts_first_footer_num'] = 4;
		register_sidebars( $mts_options['mts_first_footer_num'], array(
			'name' => __( 'First Footer %d', 'wooshop' ),
			'description'   => __( 'Appears at the top of the footer.', 'wooshop' ),
			'id' => 'footer-first',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );
	}

	// Custom sidebars
	if ( !empty( $mts_options['mts_custom_sidebars'] ) && is_array( $mts_options['mts_custom_sidebars'] )) {
		foreach( $mts_options['mts_custom_sidebars'] as $sidebar ) {
			if ( !empty( $sidebar['mts_custom_sidebar_id'] ) && !empty( $sidebar['mts_custom_sidebar_id'] ) && $sidebar['mts_custom_sidebar_id'] != 'sidebar-' ) {
				register_sidebar( array( 'name' => ''.$sidebar['mts_custom_sidebar_name'].'', 'id' => ''.sanitize_title( strtolower( $sidebar['mts_custom_sidebar_id'] )).'', 'before_widget' => '<div id="%1$s" class="widget %2$s">', 'after_widget' => '</div>', 'before_title' => '<h3>', 'after_title' => '</h3>' ));
			}
		}
	}

	if ( mts_is_wc_active() ) {
		// Register WooCommerce Shop and Single Product Sidebar
		register_sidebar( array(
			'name' => __('Shop Page Sidebar', 'wooshop' ),
			'description'   => __( 'Appears on Shop main page and product archive pages.', 'wooshop' ),
			'id' => 'shop-sidebar',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		));
		register_sidebar( array(
			'name' => __('Single Product Sidebar', 'wooshop' ),
			'description'   => __( 'Appears on single product pages.', 'wooshop' ),
			'id' => 'product-sidebar',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		));
		register_sidebar( array(
			'name' => __('Catalog Pages Ads','wooshop'),
			'id' => 'catalog-ads',
			'description'   => __( 'Appears on shop and product category archives.', 'wooshop' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3>',
			'after_title' => '</h3>'
		) );
	}
}

add_action( 'widgets_init', 'mts_register_sidebars' );

function mts_register_extra_sidebars() {
	$mts_options = get_option( MTS_THEME_NAME );
	if (!empty($mts_options['mts_category_ad_widgets_enabled']) && !empty($mts_options['mts_category_ad_widgets'])) {
		foreach( $mts_options['mts_category_ad_widgets'] as $category_id => $v ) {
			$term = get_term($category_id, 'product_cat');
			register_sidebar( array(
				'name' => $term->name. __(' Catalog Ads','wooshop'),
				'description'   => __( 'Appears on specific product category archive.', 'wooshop' ),
				'id' => 'catalog-ads-'.$category_id,
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h3>',
				'after_title' => '</h3>'
			) );
		}
	}
}
add_action( 'init', 'mts_register_extra_sidebars', 10 ); // can't run this on 'widgets_init' :/

function mts_get_excluded_sidebars() {
	$mts_options = get_option( MTS_THEME_NAME );
	$list = array();
	if (!empty( $mts_options['mts_category_ad_widgets'] )) {
		foreach( $mts_options['mts_category_ad_widgets'] as $product_cat_id => $v ) {
			$list[] = 'catalog-ads-'.$product_cat_id;
		}
	}
	return array_merge( $list, array('homepage-sidebar', 'sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-first-5', 'shop-sidebar', 'product-sidebar', 'catalog-ads') );
}

/**
 * Retrieve the ID of the sidebar to use on the active page.
 *
 * @return string
 */
function mts_custom_sidebar() {
	$mts_options = get_option( MTS_THEME_NAME );

	// Default sidebar.
	$sidebar = 'sidebar';

	if ( is_front_page() && !empty( $mts_options['mts_sidebar_for_home'] ) ) {
		$sidebar = 'homepage-sidebar';
		if ( !empty( $mts_options['mts_sidebar_for_home'] )) {
			$sidebar = $mts_options['mts_sidebar_for_home'];
		}
	}

	if ( mts_is_wc_active() ) {
		if ( is_cart() && !empty( $mts_options['mts_sidebar_for_cart'] ) ) {
			$sidebar = 'mts_nosidebar';
			if ( !empty( $mts_options['mts_sidebar_for_cart'] )) {
				$sidebar = $mts_options['mts_sidebar_for_cart'];
			}
		}
	}

	if ( mts_is_wc_active() ) {
		if ( is_checkout() && !empty( $mts_options['mts_sidebar_for_checkout'] ) ) {
			$sidebar = 'mts_nosidebar';
			if ( !empty( $mts_options['mts_sidebar_for_checkout'] )) {
				$sidebar = $mts_options['mts_sidebar_for_checkout'];
			}
		}
	}

	if ( mts_is_wc_active() && is_page('wishlist') ) {
		if ( !empty( $mts_options['mts_wishlist'] ) && !empty( $mts_options['mts_sidebar_for_wishlist'] ) ) {
			$sidebar = 'mts_nosidebar';
			if ( !empty( $mts_options['mts_sidebar_for_wishlist'] )) {
				$sidebar = $mts_options['mts_sidebar_for_wishlist'];
			}
		}
	}

	if ( is_single() && !empty( $mts_options['mts_sidebar_for_post'] )) $sidebar = $mts_options['mts_sidebar_for_post'];
	if ( is_page() && !empty( $mts_options['mts_sidebar_for_page'] )) $sidebar = $mts_options['mts_sidebar_for_page'];

	// Archives.
	if ( is_archive() && !empty( $mts_options['mts_sidebar_for_archive'] )) $sidebar = $mts_options['mts_sidebar_for_archive'];
	if ( is_category() && !empty( $mts_options['mts_sidebar_for_category'] )) $sidebar = $mts_options['mts_sidebar_for_category'];
	if ( is_tag() && !empty( $mts_options['mts_sidebar_for_tag'] )) $sidebar = $mts_options['mts_sidebar_for_tag'];
	if ( is_date() && !empty( $mts_options['mts_sidebar_for_date'] )) $sidebar = $mts_options['mts_sidebar_for_date'];
	if ( is_author() && !empty( $mts_options['mts_sidebar_for_author'] )) $sidebar = $mts_options['mts_sidebar_for_author'];

	// Other.
	if ( is_search() && !empty( $mts_options['mts_sidebar_for_search'] )) $sidebar = $mts_options['mts_sidebar_for_search'];
	if ( is_404() && !empty( $mts_options['mts_sidebar_for_notfound'] )) $sidebar = $mts_options['mts_sidebar_for_notfound'];

	// Woocommerce.
	if ( mts_is_wc_active() ) {
		if ( is_shop() || is_product_taxonomy() ) {
			$sidebar = 'shop-sidebar';
			if ( !empty( $mts_options['mts_sidebar_for_shop'] )) {
				$sidebar = $mts_options['mts_sidebar_for_shop'];
			}
		}
		if ( is_product() ) {
			$sidebar = 'product-sidebar';
			if ( !empty( $mts_options['mts_sidebar_for_product'] )) {
				$sidebar = $mts_options['mts_sidebar_for_product'];
			}
		}
		if ( is_account_page() ) {
			$sidebar = 'mts_nosidebar';
		}
	}

	// Page/post specific custom sidebar-
	if ( is_page() || is_single() ) {
		wp_reset_postdata();
		global $wp_registered_sidebars;
		$custom = get_post_meta( get_the_ID(), '_mts_custom_sidebar', true );
		if ( !empty( $custom ) && array_key_exists( $custom, $wp_registered_sidebars ) || 'mts_nosidebar' == $custom ) {
			$sidebar = $custom;
		}
	}

	// Posts page
	if ( is_home() && ! is_front_page() && 'page' == get_option( 'show_on_front' ) ) {
		wp_reset_postdata();
		global $wp_registered_sidebars;
		$custom = get_post_meta( get_option( 'page_for_posts' ), '_mts_custom_sidebar', true );
		if ( !empty( $custom ) && array_key_exists( $custom, $wp_registered_sidebars ) || 'mts_nosidebar' == $custom ) {
			$sidebar = $custom;
		}
	}

	return apply_filters( 'mts_custom_sidebar', $sidebar );
}

/*-----------------------------------------------------------------------------------*/
/*  Load Widgets, Actions and Libraries
/*-----------------------------------------------------------------------------------*/

include_once( get_theme_file_path( "functions/widget-ad.php" ) );

// Add the 125x125 Ad Block Custom Widget.
include_once( get_theme_file_path( "functions/widget-ad125.php" ) );

// Add the 250x250 Ad Block Custom Widget.
include_once( get_theme_file_path( "functions/widget-ad250.php" ) );

// Add the Latest Tweets Custom Widget.
include_once( get_theme_file_path( "functions/widget-tweets.php" ) );

// Add Recent Posts Widget.
include_once( get_theme_file_path( "functions/widget-recentposts.php" ) );

// Add Related Posts Widget.
include_once( get_theme_file_path( "functions/widget-relatedposts.php" ) );

// Add Author Posts Widget.
include_once( get_theme_file_path( "functions/widget-authorposts.php" ) );

// Add Popular Posts Widget.
include_once( get_theme_file_path( "functions/widget-popular.php" ) );

// Add Facebook Like box Widget.
include_once( get_theme_file_path( "functions/widget-fblikebox.php" ) );

// Add Social Profile Widget.
include_once( get_theme_file_path( "functions/widget-social.php" ) );

// Add Category Posts Widget.
include_once( get_theme_file_path( "functions/widget-catposts.php" ) );

// Add Category Posts Widget.
include_once( get_theme_file_path( "functions/widget-postslider.php" ) );

if ( mts_is_wc_active() ) {
	// Add Ajax filter widget
	include_once( get_theme_file_path( "functions/widget-ajax-layered-nav.php" ) );
}

// Add Adcode Widget.
include_once( get_theme_file_path( "functions/widget-adcode.php" ) );

// Add Welcome message.
include_once( get_theme_file_path( "functions/welcome-message.php" ) );

// Template Functions.
include_once( get_theme_file_path( "functions/theme-actions.php" ) );

// Post/page editor meta boxes.
include_once( get_theme_file_path( "functions/metaboxes.php" ) );

// TGM Plugin Activation.
include_once( get_theme_file_path( "functions/plugin-activation.php" ) );

// AJAX Contact Form - `mts_contact_form()`.
include_once( get_theme_file_path( 'functions/contact-form.php' ) );

// Custom menu walker.
include_once( get_theme_file_path( 'functions/nav-menu.php' ) );

/**
 * RTL
 */
if ( ! empty( $mts_options['mts_rtl'] ) ) {
	/**
	 * RTL language support
	 *
	 * @see mts_load_footer_scripts()
	 */
	function mts_rtl() {
		if ( is_admin() ) {
			return;
		}
		global $wp_locale, $wp_styles;
		$wp_locale->text_direction = 'rtl';
		if ( ! is_a( $wp_styles, 'WP_Styles' ) ) {
			$wp_styles = new WP_Styles();
			$wp_styles->text_direction = 'rtl';
		}
	}
	add_action( 'init', 'mts_rtl' );
}

/**
 * Replace `no-js` with `js` from the body's class name.
 */
function mts_nojs_js_class() {
	echo '<script type="text/javascript">document.documentElement.className = document.documentElement.className.replace( /\bno-js\b/,\'js\' );</script>';
}
add_action( 'wp_head', 'mts_nojs_js_class', 1 );

/**
 * Enqueue .js files.
 */
function mts_add_scripts() {
	$mts_options = get_option( MTS_THEME_NAME );

	wp_enqueue_script( 'jquery' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_register_script( 'customscript', get_template_directory_uri() . '/js/customscript.js', array( 'jquery' ), MTS_THEME_VERSION, true );
	if ( ! empty( $mts_options['mts_show_primary_nav'] ) ) {
		$nav_menu = 'both';
	} else {
		$nav_menu = 'none';

		if ( ! empty( $mts_options['mts_show_primary_nav'] ) ) {
			$nav_menu = 'primary-menu';
		}
	}
	wp_localize_script(
		'customscript',
		'mts_customscript',
		array(
			'responsive' => ( empty( $mts_options['mts_responsive'] ) ? false : true ),
			'nav_menu' => $nav_menu
		)
	);
	wp_enqueue_script( 'customscript' );

	// Slider
	wp_register_script('owl-carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array(), null, true);
	wp_localize_script('owl-carousel', 'slideropts', array('rtl_support' => $mts_options['mts_rtl']));
	wp_enqueue_script ('owl-carousel');

	// Ajax nav for widget
	wp_register_script( 'wc-ajax-attr-filters', get_template_directory_uri() . '/js/wc-ajax-attr-filters.js' );

	// Animated single post/page header
	if ( is_singular() ) {
		$header_animation = mts_get_post_header_effect();
		if ( 'parallax' == $header_animation ) {
			wp_enqueue_script( 'jquery-parallax', get_template_directory_uri() . '/js/parallax.js', array( 'jquery' ) );
		} else if ( 'zoomout' == $header_animation ) {
			wp_enqueue_script( 'jquery-zoomout', get_template_directory_uri() . '/js/zoomout.js', array( 'jquery' ) );
		}
	}

	//Lightbox
	global $mts_size_chart_popup;
	if ( ! empty( $mts_options['mts_lightbox'] ) || ( mts_is_wc_active() && is_product() && !empty( $mts_size_chart_popup ) ) ) {
		wp_enqueue_script( 'magnificPopup', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array( 'jquery' ) );
	}

	//Sticky Nav
	if ( ! empty( $mts_options['mts_sticky_nav'] ) ) {
		wp_enqueue_script( 'StickyNav', get_template_directory_uri() . '/js/sticky.js' );
	}

	// Lazy Load
	if ( ! empty( $mts_options['mts_lazy_load'] ) ) {
		if ( ! empty( $mts_options['mts_lazy_load_thumbs'] ) || ( ! empty( $mts_options['mts_lazy_load_content'] ) && is_singular() ) ) {
			wp_enqueue_script( 'layzr', get_template_directory_uri() . '/js/layzr.min.js', '', '', true );
		}
	}

	// Ajax Load More and Search Results
	wp_register_script( 'mts_cookie', get_template_directory_uri() . '/js/jquery.cookie.js', true );
	wp_register_script( 'mts_ajax', get_template_directory_uri() . '/js/ajax.js', true );
	if ( ( ((is_archive() && function_exists('is_woocommerce') && !is_woocommerce()) || is_home()) && ! empty( $mts_options['mts_pagenavigation_type'] ) && $mts_options['mts_pagenavigation_type'] >= 2 ) ||
	 ( function_exists('is_woocommerce') && is_woocommerce() && !empty( $mts_options['mts_shop_pagenavigation_type'] ) && $mts_options['mts_shop_pagenavigation_type'] >= 1 ) ) {
		wp_enqueue_script( 'mts_ajax' );

		wp_enqueue_script( 'historyjs', get_template_directory_uri() . '/js/history.js' );

		// Add parameters for the JS
		global $latest_posts;
		global $wp_query;
		$max = (! empty($latest_posts->max_num_pages) ? $latest_posts->max_num_pages : $wp_query->max_num_pages);
		if ($max == 0 && is_home() ) {
			if (get_query_var('page') > 1) {
				$paged = get_query_var('page');
			} elseif (get_query_var('paged')) {
				$paged = get_query_var('paged');
			} else {
				$paged = 1;
			}
			$new_query = new WP_Query(array('paged' => $paged, 'post_type' => 'post'));
			$max = $new_query->max_num_pages;
		}
		$paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
		$autoload = ( (is_woocommerce() && $mts_options['mts_shop_pagenavigation_type'] == 2 ) || ( ( (is_archive() && !is_woocommerce() ) || is_home() ) && $mts_options['mts_pagenavigation_type'] == 3 ) );
		wp_localize_script(
			'mts_ajax',
			'mts_ajax_loadposts',
			array(
				'startPage' => $paged,
				'maxPages' => $max,
				'nextLink' => next_posts( $max, false ),
				'autoLoad' => $autoload,
				'is_shop' => function_exists('is_woocommerce') && is_woocommerce(),
				'i18n_loadmore' => __( 'Load More Posts', 'wooshop' ),
				'i18n_loading' => __('Loading...', 'wooshop' ),
				'i18n_nomore' => __( 'No more posts.', 'wooshop' )
			 )
		);
	}
	if ( ! empty( $mts_options['mts_ajax_search'] ) ) {
		wp_enqueue_script( 'mts_ajax' );
		wp_localize_script(
			'mts_ajax',
			'mts_ajax_search',
			array(
				'url' => admin_url( 'admin-ajax.php' ),
				'ajax_search' => '1'
			 )
		);
	}
	if ( mts_is_wc_active() && isset( $mts_options['mts_wishlist'] ) && !empty( $mts_options['mts_wishlist'] ) ) {
		wp_enqueue_script( 'mts_cookie' );
		wp_enqueue_script( 'mts_ajax' );
		wp_localize_script(
			'mts_ajax',
			'mts_ajax_wishlist',
			array(
				'url' => admin_url( 'admin-ajax.php' ),
			)
		);
	}

}
add_action( 'wp_enqueue_scripts', 'mts_add_scripts' );

/**
 * Load CSS files.
 */
function mts_enqueue_css() {
	$mts_options = get_option( MTS_THEME_NAME );

	wp_enqueue_style( 'wooshop-stylesheet', get_stylesheet_uri() );

	// Slider
	// also enqueued in slider widget
	wp_register_style('owl-carousel', get_template_directory_uri() . '/css/owl.carousel.css', array(), null);
	wp_enqueue_style('owl-carousel');

	$handle = 'wooshop-stylesheet';

	// Responsive
	if ( ! empty( $mts_options['mts_responsive'] ) ) {
		wp_enqueue_style( 'responsive', get_template_directory_uri() . '/css/responsive.css' );
	}

	// WooCommerce
	if ( mts_is_wc_active() ) {
		wp_enqueue_style( 'woocommerce', get_template_directory_uri() . '/css/woocommerce2.css' );
		$handle = 'woocommerce';
	}

	// RTL
	if ( ! empty( $mts_options['mts_rtl'] ) ) {
		wp_enqueue_style( 'mts_rtl', get_template_directory_uri() . '/css/rtl.css', 'wooshop-style' );
	}

	// Lightbox
	global $mts_size_chart_popup;
	if ( ! empty( $mts_options['mts_lightbox'] ) || ( mts_is_wc_active() && is_product() && !empty( $mts_size_chart_popup ) ) ) {
		wp_register_style( 'magnificPopup', get_template_directory_uri() . '/css/magnific-popup.css' );
		wp_enqueue_style( 'magnificPopup' );
	}

	// Font Awesome
	wp_register_style( 'fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css' );
	wp_enqueue_style( 'fontawesome' );

	$mts_blog_layout = '';
	$mts_shop_layout = '';
	$mts_shareit_left = '';
	$mts_shareit_right = '';
	$mts_author = '';
	$mts_header_section = '';
	$mts_sidebar_location = '';
	$mts_prim_menu = '';
	$mts_post_format_icons = '';

	if ( is_page() || is_single() ) {
		$mts_sidebar_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}
	if ( $mts_sidebar_location != 'right' && ( $mts_options['mts_layout'] == 'sclayout' || $mts_sidebar_location == 'left' )) {
		$mts_blog_layout = '.article { float: right;}
		.sidebar.c-4-12 { float: left; padding-right: 0; }';
		if( isset( $mts_options['mts_social_button_position'] ) && $mts_options['mts_social_button_position'] == 'floating' ) {
			$mts_shareit_right = '.shareit { margin: 0 685px 0; border-left: 0; }';
		}
	}
	if ( $mts_options['mts_shop_layout'] == 'cslayout' ) {
		$mts_shop_layout = '.woocommerce .article, .woocommerce-page .article { float: left;}
		.woocommerce .sidebar.c-4-12, .woocommerce-page .sidebar.c-4-12 { float: right; }';
	}
	if ( empty( $mts_options['mts_header_section2'] ) ) {
		$mts_header_section = '.logo-wrap, .widget-header { display: none; } .header-lower-section { float: left; width: 100%; } .header-lower-right-section { float: left; width: 100%; } .mts-cart { float: right; }';
	}
	if ( $mts_options['mts_show_primary_nav'] != '1' ) {
		$mts_prim_menu = '.navigation-wrap { padding: 0; } .header-lower-section { margin-top: 50px; }';
	}
	if ( isset( $mts_options['mts_social_button_position'] ) && $mts_options['mts_social_button_position'] == 'floating' ) {
		$mts_shareit_left = '.shareit { top: 282px; left: auto; margin: 0 0 0 -123px; width: 90px; position: fixed; padding: 5px; border:none;}
		.share-item {margin-bottom: 5px;}';
	}
	if ( ! empty( $mts_options['mts_author_comment'] ) ) {
		$mts_author = '.bypostauthor { background: #FFFFFF; }
		.bypostauthor:after { content: "'.__( 'Author', 'wooshop' ).'"; position: absolute; right: -1px; top: -1px; padding: 1px 10px; background: #2d2a32; color: #FFF; font-size: 13px; text-transform: uppercase; }';
	}
	if ( !$mts_options['mts_post_format_icons'] ) {
		$mts_post_format_icons = '.blog-slider .owl-item.active .slide-caption .slide-right, .latestpost-header { margin-left: 0; }';
	}
	$mts_bg = mts_get_background_styles( 'mts_background' );
	$mts_footer_bg = mts_get_background_styles( 'mts_footer_background' );
	$hex_color1 = mts_convert_hex_to_rgb($mts_options['mts_color_scheme']);
	$hex_color2 = mts_convert_hex_to_rgb($mts_options['mts_second_color_scheme']);
	$custom_css = "
		body {{$mts_bg}}
		.navigation ul ul li, .sticky-navigation-active, .mobile-menu-active .navigation.mobile-menu-wrapper { background-color: {$mts_options['mts_background']['color']}; }
		.footer-widgets {{$mts_footer_bg}}
		.navigation ul li:hover > a, .navigation ul ul li:hover > a, .navigation ul li.current-menu-item > a { color: {$mts_options['mts_primary_nav_hover']}; }
		.mts-cart { background-color: {$mts_options['mts_header_cart_bg_color']}; color: {$mts_options['mts_header_cart_color']}; }
		.mts-cart a, .mts-cart a:hover { color: {$mts_options['mts_header_cart_color']}; }
		.mts-checkout a { background-color: {$mts_options['mts_header_checkout_bg_color']}; color: {$mts_options['mts_header_checkout_color']}; }
		.call-to-action-button a { background-color: {$mts_options['mts_call_to_action_button_color']}; }

		a, #site-footer .widget li:hover > a, #site-footer .widget .post-title a:hover, #site-footer .widget li a:hover, #site-footer .widget .wpt_widget_content a:hover, #site-footer .widget .wp_review_tab_widget_content a:hover, #site-footer .widget li:hover > .toggle-caret, .sidebar .widget li a:hover, .woocommerce .sidebar .widget .current-cat > a { color: {$mts_options['mts_color_scheme']}; }
		.widget .review-star .review-result, #site-footer .textwidget address a:hover, .woocommerce div.product .stock, #copyright-note > span a:hover { color: {$mts_options['mts_color_scheme']}!important; }

		.pace .pace-progress, .pagination  .nav-previous a:hover, .pagination .nav-next a:hover, .tagcloud a:hover, .tags a:hover, #commentform input#submit, .contact-form input[type='\submit'], #site-footer .tagcloud a:hover, body .owl-prev:hover, body .owl-next:hover, .slider-product-button:hover, .page-numbers.current, #load-posts a:hover, .mts-cart:hover, .mts-checkout a:hover, .currenttext, input[type='submit'], .ball-pulse > div, .woocommerce-account .woocommerce-MyAccount-navigation ul li.is-active a, body .owl-controls .owl-dot.active span, body .owl-controls .owl-dot:hover span, .pagination a:hover, .woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current, #move-to-top:hover, .woocommerce div.product form.cart .single_add_to_cart_button.button, .woocommerce a.button, .woocommerce-page a.button, .woocommerce button.button, .woocommerce-page button.button, .woocommerce input.button, .woocommerce-page input.button, .woocommerce #respond input#submit, .woocommerce-page #respond input#submit, .woocommerce #content input.button, .woocommerce-page #content input.button, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce .widget_price_filter .ui-slider .ui-slider-range, .widget .wp-subscribe-wrap input.submit { background-color: {$mts_options['mts_color_scheme']}; color: #fff; }

		.tagcloud a:hover, .tags a:hover, #site-footer .tagcloud a:hover, #load-posts a:hover, input[type='submit'] { border-color: {$mts_options['mts_color_scheme']}; }

		.woocommerce a.add_to_cart_button, .woocommerce-page a.add_to_cart_button { background-color: rgba($hex_color1, 0.8 );}

		a:hover, .woocommerce .cart-wishlist-button .mts-add-to-wishlist, .woocommerce .cart-wishlist-button .mts-add-to-wishlist:hover, .woocommerce .woocommerce-breadcrumb > a:hover { color: {$mts_options['mts_second_color_scheme']}; }

		.slider-product-heading, .post-format-icons, #commentform input#submit:hover, .contact-form input[type='\submit']:hover, .widget .widget-slider .slide-caption, .widget #wp-subscribe { background-color: {$mts_options['mts_second_color_scheme']}; }

		.woocommerce ul.products li.product .onsale-badge, .woocommerce span.onsale-badge, .woocommerce-page span.onsale-badge { background-color: rgba($hex_color2, 0.9 ); }

		{$mts_blog_layout}
		{$mts_shop_layout}
		{$mts_shareit_left}
		{$mts_shareit_right}
		{$mts_author}
		{$mts_header_section}
		{$mts_prim_menu}
		{$mts_post_format_icons}
		{$mts_options['mts_custom_css']}
			";
	wp_add_inline_style( $handle, $custom_css );
}
add_action( 'wp_enqueue_scripts', 'mts_enqueue_css', 99 );

/**
 * Wrap videos in .responsive-video div
 *
 * @param $html
 * @param $url
 * @param $attr
 *
 * @return string
 */
function mts_responsive_video( $html, $url, $attr ) {

	// Only video embeds
	$video_providers = array(
		'youtube',
		'vimeo',
		'dailymotion',
		'wordpress.tv',
		'vine.co',
		'animoto',
		'blip.tv',
		'collegehumor.com',
		'funnyordie.com',
		'hulu.com',
		'revision3.com',
		'ted.com',
	);

	// Allow user to wrap other embeds
	$providers = apply_filters('mts_responsive_video', $video_providers );

	foreach ( $providers as $provider ) {
		if ( strstr($url, $provider) ) {
			$html = '<div class="flex-video flex-video-' . sanitize_html_class( $provider ) . '">' . $html . '</div>';
			break;// Break if video found
		}
	}

	return $html;
}
add_filter( 'embed_oembed_html', 'mts_responsive_video', 99, 3 );

/**
 * Custom comments template.
 * @param $comment
 * @param $args
 * @param $depth
 */
if ( ! function_exists( 'mts_comments' ) ) {
	function mts_comments( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		$mts_options = get_option( MTS_THEME_NAME ); ?>
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
			<?php
			switch( $comment->comment_type ) :
				case 'pingback':
				case 'trackback': ?>
					<div id="comment-<?php comment_ID(); ?>" class="comment-list">
						<div class="comment-author vcard">
							Pingback: <?php comment_author_link(); ?>
							<span class="comment-meta">
								<?php edit_comment_link( __( '( Edit )', 'wooshop' ), '  ', '' ) ?>
							</span>
						</div>
						<?php if ( ! empty( $mts_options['mts_comment_date'] ) ) { ?>
							<span class="ago"><?php comment_date( get_option( 'date_format' ) ); ?></span>
						<?php } ?>
						<?php if ( $comment->comment_approved == '0' ) : ?>
							<em><?php _e( 'Your comment is awaiting moderation.', 'wooshop' ) ?></em>
							<br />
						<?php endif; ?>
					</div>
				<?php
				break;

				default: ?>
					<div id="comment-<?php comment_ID(); ?>" class="comment-list" itemscope itemtype="http://schema.org/UserComments">
						<?php echo get_avatar( $comment->comment_author_email, 70 ); ?>
						<div class="comment-author vcard">
							<?php printf( '<h6 class="fn" itemprop="creator" itemscope itemtype="http://schema.org/Person"><span itemprop="name">%s</span></h6>', get_comment_author_link() ) ?>
							<span class="comment-meta">
								<?php edit_comment_link( __( '( Edit )', 'wooshop' ), '  ', '' ) ?>
							</span>
							<?php if ( $comment->comment_approved == '0' ) : ?>
								<em><?php _e( 'Your comment is awaiting moderation.', 'wooshop' ) ?></em>
								<br />
							<?php endif; ?>
							<div class="commenttext" itemprop="commentText">
								<?php comment_text() ?>
							</div>
							<?php if ( ! empty( $mts_options['mts_comment_date'] ) ) { ?>
								<span class="ago"><?php comment_date( get_option( 'date_format' ) ); ?></span>
							<?php } ?>
							<div class="reply">
								<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] )) ) ?>
							</div>
						</div>
					</div>
				<?php
			   break;
			 endswitch; ?>
		<!-- WP adds </li> -->
	<?php }
}

/**
 * Increase excerpt length to 100.
 *
 * @param $length
 *
 * @return int
 */
function mts_excerpt_length( $length ) {
	return 100;
}
add_filter( 'excerpt_length', 'mts_excerpt_length', 20 );

/**
 * Remove [...] and shortcodes
 *
 * @param $output
 *
 * @return string
 */
function mts_custom_excerpt( $output ) {
  return preg_replace( '/\[[^\]]*]/', '', $output );
}
add_filter( 'get_the_excerpt', 'mts_custom_excerpt' );

/**
 * Truncate string to x letters/words.
 *
 * @param $str
 * @param int $length
 * @param string $units
 * @param string $ellipsis
 *
 * @return string
 */
function mts_truncate( $str, $length = 40, $units = 'letters', $ellipsis = '&nbsp;&hellip;' ) {
	if ( $units == 'letters' ) {
		if ( mb_strlen( $str ) > $length ) {
			return mb_substr( $str, 0, $length ) . $ellipsis;
		} else {
			return $str;
		}
	} else {
		return wp_trim_words( $str, $length, $ellipsis );
	}
}

if ( ! function_exists( 'mts_excerpt' ) ) {
	/**
	 * Get HTML-escaped excerpt up to the specified length.
	 *
	 * @param int $limit
	 *
	 * @return string
	 */
	function mts_excerpt( $limit = 40 ) {
	  return esc_html( mts_truncate( get_the_excerpt(), $limit, 'words' ) );
	}
}

/**
 * Change the "read more..." link to "".
 * @param $more_link
 * @param $more_link_text
 *
 * @return string
 */
function mts_remove_more_link( $more_link, $more_link_text ) {
	return '';
}
add_filter( 'the_content_more_link', 'mts_remove_more_link', 10, 2 );

if ( ! function_exists( 'mts_post_has_moretag' ) ) {
	/**
	 * Shorthand function to check for more tag in post.
	 *
	 * @return bool|int
	 */
	function mts_post_has_moretag() {
		$post = get_post();
		return preg_match( '/<!--more(.*?)?-->/', $post->post_content );
	}
}

if ( ! function_exists( 'mts_readmore' ) ) {
	/**
	 * Display a "read more" link.
	 */
	function mts_readmore() {
		?>
		<div class="readMore">
			<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php echo esc_attr( get_the_title() ); ?>">
				<?php _e( 'Read More', 'wooshop' ); ?>
			</a>
		</div>
		<?php
	}
}

/**
 * Exclude trackbacks from the comment count.
 *
 * @param $count
 *
 * @return int
 */
function mts_comment_count( $count ) {
	if ( ! is_admin() ) {
		global $id;
		$comments = get_comments( 'status=approve&post_id=' . $id );
		$comments_by_type = separate_comments( $comments );
		return count( $comments_by_type['comment'] );
	} else {
		return $count;
	}
}
add_filter( 'get_comments_number', 'mts_comment_count', 0 );

/**
 * Add `has_thumb` to the post's class name if it has a thumbnail.
 *
 * @param $classes
 *
 * @return array
 */
function has_thumb_class( $classes ) {
	if( has_post_thumbnail( get_the_ID() ) ) { $classes[] = 'has_thumb'; }
		return $classes;
}
add_filter( 'post_class', 'has_thumb_class' );

/**
 * Add the title tag for compability with older WP versions.
 */
if ( ! function_exists( '_wp_render_title_tag' ) ) {
	function theme_slug_render_title() { ?>
	   <title><?php wp_title( '|', true, 'right' ); ?></title>
	<?php }
	add_action( 'wp_head', 'theme_slug_render_title' );
}

/**
 * Handle AJAX search queries.
 */
if( ! function_exists( 'ajax_mts_search' ) ) {
	function ajax_mts_search() {
		$query = $_REQUEST['q']; // It goes through esc_sql() in WP_Query
		$search_query = new WP_Query( array( 's' => $query, 'posts_per_page' => 3, 'post_status' => 'publish' ));
		$search_count = new WP_Query( array( 's' => $query, 'posts_per_page' => -1, 'post_status' => 'publish' ));
		$search_count = $search_count->post_count;
		if ( !empty( $query ) && $search_query->have_posts() ) :
			//echo '<h5>Results for: '. $query.'</h5>';
			echo '<ul class="ajax-search-results">';
			while ( $search_query->have_posts() ) : $search_query->the_post();
				?><li>
					<a href="<?php echo esc_url( get_the_permalink() ); ?>">
						<?php if ( has_post_thumbnail() ) { ?>
							<?php the_post_thumbnail( 'wooshop-widgetthumb', array( 'title' => '' ) ); ?>
						<?php } else { ?>
							<img class="wp-post-image" src="<?php echo get_template_directory_uri() . '/images/nothumb-wooshop-widgetthumb.png'; ?>" alt="<?php echo esc_attr( get_the_title() ); ?>"/>
						<?php } ?>
						<?php the_title(); ?>
					</a>
					<div class="meta">
						<span class="thetime"><?php the_time( 'F j, Y' ); ?></span>
					</div> <!-- / .meta -->
				</li>
				<?php
			endwhile;
			echo '</ul>';
			echo '<div class="ajax-search-meta"><span class="results-count">'.$search_count.' '.__( 'Results', 'wooshop' ).'</span><a href="'.esc_url( get_search_link( $query ) ).'" class="results-link">'.__('Show all results.', 'wooshop' ).'</a></div>';
		else:
			echo '<div class="no-results">'.__( 'No results found.', 'wooshop' ).'</div>';
		endif;
		wp_reset_postdata();
		exit; // required for AJAX in WP
	}
}	
if( !empty( $mts_options['mts_ajax_search'] )) {
	add_action( 'wp_ajax_mts_search', 'ajax_mts_search' );
	add_action( 'wp_ajax_nopriv_mts_search', 'ajax_mts_search' );
}

/**
 *  Filters that allow shortcodes in Text Widgets
 */
add_filter( 'widget_text', 'shortcode_unautop' );
add_filter( 'widget_text', 'do_shortcode' );
add_filter( 'the_content_rss', 'do_shortcode' );

if ( trim( $mts_options['mts_feedburner'] ) !== '' ) {
	/**
	 * Redirect feed to FeedBurner if a FeedBurner URL has been set.
	 */
	function mts_rss_feed_redirect() {
		$mts_options = get_option( MTS_THEME_NAME );
		global $feed;
		$new_feed = $mts_options['mts_feedburner'];
		if ( !is_feed() ) {
				return;
		}
		if ( preg_match( '/feedburner/i', $_SERVER['HTTP_USER_AGENT'] )){
				return;
		}
		if ( $feed != 'comments-rss2' ) {
				if ( function_exists( 'status_header' )) status_header( 302 );
				header( "Location:" . $new_feed );
				header( "HTTP/1.1 302 Temporary Redirect" );
				exit();
		}
	}
	add_action( 'template_redirect', 'mts_rss_feed_redirect' );
}

/**
 * Single Post Pagination - Numbers + Previous/Next.
 *
 * @param $args
 *
 * @return mixed
 */
function mts_wp_link_pages_args( $args ) {
	global $page, $numpages, $more, $pagenow;
	if ( $args['next_or_number'] != 'next_and_number' ) {
		return $args;
	}

	$args['next_or_number'] = 'number';

	if ( !$more ) {
		return $args;
	}

	if( $page-1 ) {
		$args['before'] .= _wp_link_page( $page-1 )
						. $args['link_before']. $args['previouspagelink'] . $args['link_after'] . '</a>';
	}

	if ( $page<$numpages ) {
		$args['after'] = _wp_link_page( $page+1 )
						 . $args['link_before'] . $args['nextpagelink'] . $args['link_after'] . '</a>'
						 . $args['after'];
	}

	return $args;
}
add_filter( 'wp_link_pages_args', 'mts_wp_link_pages_args' );

/**
 * Remove hentry class from pages
 *
 * @param $classes
 *
 * @return array
 */
function mts_remove_hentry( $classes ) {
	if ( is_page() ) {
		$classes = array_diff( $classes, array( 'hentry' ) );
	}
	return $classes;
}
add_filter( 'post_class','mts_remove_hentry' );

/**
 * WooCommerce
 */
if ( mts_is_wc_active() ) {
	if ( !function_exists( 'mts_loop_columns' )) {
		/**
		 * Change number or products per row to 3
		 *
		 * @return int
		 */
		function mts_loop_columns() {
			return 4; // 4 products per row
		}
	}
	add_filter( 'loop_shop_columns', 'mts_loop_columns' );

	/**
	 * Redefine woocommerce_output_related_products()
	 */
	if( ! function_exists( 'woocommerce_output_related_products' ) ) {
		function woocommerce_output_related_products() {
			$args = array(
				'posts_per_page' => 4,
				'columns' => 4,
			);
			woocommerce_related_products($args);
		}
	}

	global $pagenow;
	if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) {
		/**
		 * Define WooCommerce image sizes.
		 */
		function mts_woocommerce_image_dimensions() {
			$catalog = array(
				'width' 	=> '184',	// px
				'height'	=> '220',	// px
				'crop'		=> 1 		// true
			);
			$single = array(
				'width' 	=> '520',	// px
				'height'	=> '430',	// px
				'crop'		=> 1 		// true
			);
			$thumbnail = array(
				'width' 	=> '130',	// px
				'height'	=> '110',	// px
				'crop'		=> 1 		// false
			);
			// Image sizes
			update_option( 'shop_catalog_image_size', $catalog ); 		// Product category thumbs
			update_option( 'shop_single_image_size', $single ); 		// Single product image
			update_option( 'shop_thumbnail_image_size', $thumbnail ); 	// Image gallery thumbs
		}
		add_action( 'init', 'mts_woocommerce_image_dimensions', 1 );
	}


	/**
	 * Change the number of product thumbnails to show per row to 4.
	 *
	 * @return int
	 */
	function mts_thumb_cols() {
	 return 4; // .last class applied to every 4th thumbnail
	}
	add_filter( 'woocommerce_product_thumbnails_columns', 'mts_thumb_cols' );

	/**
	 * Change the number of WooCommerce products to show per page.
	 *
	 * @return mixed
	 */
	function mts_products_per_page() {
		$mts_options = get_option( MTS_THEME_NAME );
		return $mts_options['mts_shop_products'];
	}
	add_filter( 'loop_shop_per_page', 'mts_products_per_page', 20 );

	/**
	 * Ensure cart contents update when products are added to the cart via AJAX.
	 *
	 * @param $fragments
	 *
	 * @return mixed
	 */
	function mts_header_add_to_cart_fragment( $fragments ) {
		global $woocommerce;
		ob_start();	?>

		<a class="cart-contents" href="<?php echo esc_url( wc_get_cart_url() ); ?>" title="<?php _e( 'View your shopping cart', 'wooshop' ); ?>"><?php echo sprintf( _n( '%d item', '%d items', $woocommerce->cart->cart_contents_count, 'wooshop' ), $woocommerce->cart->cart_contents_count );?></a>

		<?php $fragments['a.cart-contents'] = ob_get_clean();
		return $fragments;
	}
	$add_to_cart_fragments_action = version_compare( WC()->version, '3.0.0', ">=" ) ? 'woocommerce_add_to_cart_fragments' : 'add_to_cart_fragments';
	add_filter( $add_to_cart_fragments_action, 'mts_header_add_to_cart_fragment' );

	// Change add to cart text on single products
	add_filter( 'woocommerce_product_single_add_to_cart_text', 'woo_custom_cart_button_text', 10, 2 );
	function woo_custom_cart_button_text($text, $product) {
		if ( $product->is_type( 'external' ) ) return $text;
		return __( 'Add to Cart', 'wooshop' );
	}

	// Remove WooCommerce generator tag.
	remove_action('wp_head', 'wc_generator_tag');

	// Add extra classes to body
	add_filter( 'body_class', 'mts_body_classes' );
	function mts_body_classes( $classes ) {
		$mts_options = get_option( MTS_THEME_NAME );
		if ( !isset( $mts_options['mts_wishlist'] ) || empty( $mts_options['mts_wishlist'] ) ) {
			$classes[] = 'wishlist-disabled';
		}
		return $classes;
	}

	// Remove link, rating and default button in products loop
	remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );

	/**
	* Output placeholders for the single variation.
	*/
	function woocommerce_single_variation() {
		echo '<div class="single_variation clear"></div>';
	}

	add_action( 'woocommerce_before_add_to_cart_button', 'mts_wc_single_product_wishlist_wrapper',10000 );
	function mts_wc_single_product_wishlist_wrapper() {
		echo '<div class="cart-wishlist-button">';
	}

	add_action( 'woocommerce_after_add_to_cart_button', 'mts_wc_single_product_wishlist' );
	function mts_wc_single_product_wishlist() {
		echo mts_wishlist_link();
		echo '</div>';
	}

	function mts_get_wishlist_page_url() {
		$wishlist_page = get_page_by_title( 'Wishlist' );
		$wishlist_page_id = apply_filters( 'mts_wishlist_page_id', $wishlist_page->ID );
		return get_page_link( $wishlist_page_id );
	}

	function mts_is_wishlist_page() {
		$wishlist_page = get_page_by_title( 'Wishlist' );
		$wishlist_page_id = apply_filters( 'mts_wishlist_page_id', $wishlist_page->ID );
		return is_page( $wishlist_page_id );
	}

	function mts_product_in_wishlist( $id ) {
		$wishlist_items = !empty( $_COOKIE['mts_wishlist'] ) ? explode(',', $_COOKIE['mts_wishlist']) : array();
		return in_array( $id, $wishlist_items );
	}

	add_action('wp_ajax_mts_wishlist_page_loop', 'mts_wishlist_page_loop');
	add_action('wp_ajax_nopriv_mts_wishlist_page_loop', 'mts_wishlist_page_loop');
	function mts_wishlist_page_loop() {
		global $mts_options;
		if ( !isset( $mts_options['mts_wishlist'] ) || empty( $mts_options['mts_wishlist'] ) ) {
			echo '<p>'.__( 'Wishlist feature is disabled', 'wooshop' ).'</p>';
			return;
		}
		echo '<table class="shop_table cart mts-wishlist-table" cellspacing="0">';
			echo '<tbody>';
			$wishlist_items = !empty( $_COOKIE['mts_wishlist'] ) ? explode(',', $_COOKIE['mts_wishlist']) : array();
			if ( !empty( $wishlist_items ) ) {
				$args = array(
					'post_type'		   => 'product',
					'post_status'		 => 'publish',
					'ignore_sticky_posts' => 1,
					'posts_per_page'	  => -1,
					'post__in'			=> $wishlist_items
				);
				$wishlist_query = new WP_Query( apply_filters( 'mts_wishlist_query', $args ) );

				while ( $wishlist_query->have_posts() ) : $wishlist_query->the_post();
					global $product;
					$pr_id = get_the_ID(); ?>
					<tr class="mts-wishlist-table-row">
						<td class="product-remove">
							<a href="#" data-product-id="<?php echo $pr_id; ?>" class="mts-remove-from-wishlist remove" title="<?php _e( 'Remove this product', 'wooshop' ) ?>">&times;</a>
						</td>
						<td class="product-thumbnail">
							<?php $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $product->get_image() );
							if ( ! $product->is_visible() )
								echo $thumbnail;
							else
								printf( '<a href="%s">%s</a>', $product->get_permalink(), $thumbnail );
							?>
						</td>
						<td class="product-name">
							<a href="<?php echo esc_url( get_permalink( apply_filters( 'woocommerce_in_cart_product', $pr_id ) ) ) ?>"><?php echo apply_filters( 'woocommerce_in_cartproduct_obj_title', $product->get_title(), $product ) ?></a>
						</td>

						<td class="product-price" data-title="<?php _e('Unit Price:', 'wooshop' ); ?>">
							<?php woocommerce_template_loop_price(); ?>
						</td>
						<td class="product-add-to-cart">
							<?php woocommerce_template_loop_add_to_cart(); ?>
						</td>
					</tr>
				<?php
				endwhile; wp_reset_postdata();
			} else {
				echo '<tr><td colspan="6" class="mts-wishlist-empty">'.__( 'Your wishlist is empty', 'wooshop' ).'</td></tr>';
			}
			echo '</tbody>';
		echo '</table>';
		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) die();
	}
	add_action('wp_ajax_mts_wishlist_count', 'mts_wishlist_count');
	add_action('wp_ajax_nopriv_mts_wishlist_count', 'mts_wishlist_count');
	function mts_wishlist_count() {
		$wishlist_items = !empty( $_COOKIE['mts_wishlist'] ) ? explode(',', $_COOKIE['mts_wishlist']) : array();
		echo count( $wishlist_items );

		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) die();
	}

	// Reorder single product tabs
	add_filter( 'woocommerce_product_tabs', 'mts_woo_product_tabs', 98 );
	function mts_woo_product_tabs( $tabs ) {

		$mts_options = get_option( MTS_THEME_NAME );

		if ( !isset( $mts_options['mts_single_product_tabs'] ) || !is_array( $mts_options['mts_single_product_tabs'] ) ) {
			return $tabs;
		}

		// Remove disabled first
		if ( array_key_exists( 'disabled', $mts_options['mts_single_product_tabs'] ) ) {
			foreach ( $mts_options['mts_single_product_tabs']['disabled'] as $tab => $title ) {
				if ( isset( $tabs[ $tab ] ) ) {
					unset( $tabs[ $tab ] );
				}
			}
		}

		// Resort enabled default tabs ( swap priority key of default tabs in case some plugin is depending on it )
		if ( array_key_exists( 'enabled', $mts_options['mts_single_product_tabs'] ) ) {

			$tabs_order = $mts_options['mts_single_product_tabs']['enabled'];

			if ( empty( $tabs_order ) ) return $tabs; // Just in case

			$default_tabs_priority=array();

			foreach ( $tabs_order as $key => $value ) {
				if ( isset( $tabs[ $key ] ) ) { // might be removed by some plugin
					$default_tabs_priority[ $tabs[ $key ]['priority'] ] = $key;
				}
			}

			$default_tabs_priority_1 = $default_tabs_priority;
			ksort( $default_tabs_priority );
			$new = array_combine( array_flip( $default_tabs_priority ), $default_tabs_priority_1 );

			foreach ( $new as $priority => $tab ) {
				if ( isset( $tabs[ $tab ] ) ) { // might be removed by some plugin
					$tabs[ $tab ]['priority'] = $priority;
				}
			}

			return $tabs;
		}

		return $tabs;
	}

	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
	add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 10 );
	add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 20 );

	if ( version_compare( WC()->version, '3.0.0', "<" ) ) {

		function mts_related_products_limit() {
			global $product;
			$orderby = '';
			$columns = 4;
			$related = $product->get_related( 4 );
			$args = array(
				'post_type'		   => 'product',
				'no_found_rows'	   => 1,
				'posts_per_page'	  => 4,
				'ignore_sticky_posts' => 1,
				'orderby'			 => $orderby,
				'post__in'			=> $related,
				'post__not_in'		=> array($product->get_id())
			);
			return $args;
		}
		add_filter( 'woocommerce_related_products_args', 'mts_related_products_limit' );
	}

	// Show single product category
	if($mts_options['mts_single_product_meta'] != '1') {
		remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
	}

	// If variation prices are present then show only current product's price
	function woocommerce_template_single_price() {
		global $product;
		if ( ! $product->is_type('variable') ) {
			wc_get_template( 'single-product/price.php' );
		}
	}
	if ( ! function_exists( 'woocommerce_template_single_price' ) ) {
		function woocommerce_template_single_price() {
			wc_get_template( 'single-product/price.php' );
		}
	}

	// Remove star reviews form single products
	if($mts_options['mts_single_product_rating'] != '1') {
		remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10);
	}

	// Show variable product price
	add_filter( 'woocommerce_show_variation_price', '__return_true' );

	/*-----------------------------------------------------------------------------------*/
	/* Add color picker option to attribute taxonomies edit screens
	/*-----------------------------------------------------------------------------------*/
	$attribute_taxonomies = wc_get_attribute_taxonomies();
	if ( $attribute_taxonomies ) {
		foreach ( $attribute_taxonomies as $tax ) {
			$attribute = sanitize_title( $tax->attribute_name );

			$taxonomy = wc_attribute_taxonomy_name( $attribute );

			add_action( $taxonomy.'_add_form_fields', 'mts_attribute_tax_add_form_fields' );
			add_action( $taxonomy.'_edit_form_fields', 'mts_attribute_tax_edit_form_fields', 10, 2 );
		}

		// Handle creating/editing/deleting of color attribute color
		add_action( 'created_term', 'mts_create_update_attribute_tax_color', 10, 3 );
		add_action( 'edited_term', 'mts_create_update_attribute_tax_color', 10, 3 );
		add_action( 'delete_term', 'mts_delete_attribute_tax_color', 10, 3 );

		// Enqueue color picker
		add_action('admin_enqueue_scripts', 'mts_attribute_tax_picker');
	}

	function mts_attribute_tax_add_form_fields() {
		?>
		<div class="form-field">
			<label for="ps_color_hex_code">
				<?php _e( 'Choose color: ', 'wooshop' ); ?>
			</label>
			<input type="text" id="ps_color_hex_code" name="ps_color_hex_code" class="mts-color-picker-field" value="">
		</div>
		<?php
	}
	function mts_attribute_tax_edit_form_fields( $tag, $taxonomy ) {
		// clear value.
		$color_code = '';

		// tag id
		$id = $tag->term_id;

		$opt_array = get_option('mts_tax_color_codes');

		if ( $opt_array && array_key_exists( $taxonomy, $opt_array ) ) {

			if ( array_key_exists( $id, $opt_array[ $taxonomy ] ) ) {

				$color_code = $opt_array[ $taxonomy ][ $id ];
			}
		}
		?>
		<tr class="form-field">
			<th scope="row" valign="top">
				<label for="ps_color_hex_code"><?php _e( 'Choose color:', 'wooshop' ); ?></label>
			</th>
			<td>
				<input type="text" id="ps_color_hex_code" name="ps_color_hex_code"  class="mts-color-picker-field" value="<?php echo $color_code; ?>">
			</td>
		</tr>

		<?php
	}
	function mts_create_update_attribute_tax_color( $term_id, $tt_id, $taxonomy ) {
		$opt_array = get_option('mts_tax_color_codes');


		if ( isset( $_POST['ps_color_hex_code'] ) ) {

			$opt_array[ $taxonomy ][ $term_id ] = $_POST['ps_color_hex_code'];
		}

		if ( isset( $opt_array ) ) {

			update_option( 'mts_tax_color_codes' , $opt_array );
		}


	}
	function mts_delete_attribute_tax_color( $term_id, $tt_id, $taxonomy ) {
		$opt_array = get_option('mts_tax_color_codes');
		if ( $opt_array && isset( $opt_array[ $taxonomy ][ $term_id ] ) ) {

			unset( $opt_array[ $taxonomy ][ $term_id ] );
			update_option('mts_tax_color_codes', $opt_array);
		}

	}
	function mts_attribute_tax_picker() {
		$taxonomy_screens = array();
		$attribute_taxonomies = wc_get_attribute_taxonomies();
		foreach ( $attribute_taxonomies as $tax ) {
			$attribute = sanitize_title( $tax->attribute_name );

			$taxonomy = wc_attribute_taxonomy_name( $attribute );

			$taxonomy_screens[] = 'edit-'.$taxonomy;
		}

		$screen = get_current_screen();
		$screen_id = $screen->id;

		if ( in_array( $screen_id, $taxonomy_screens ) ) {
			wp_enqueue_style('wp-color-picker');
			wp_enqueue_script('wp-color-picker');

			wp_enqueue_script( 'mts-color-picker-script', get_template_directory_uri() . '/js/color-picker.js', array('wp-color-picker') );

		}
	}

	// Override woocommerce_show_product_images() function
	function woocommerce_show_product_images() {
		$mts_options = get_option( MTS_THEME_NAME );
		if ( '1' === $mts_options['mts_single_product_slider'] ) {
			wc_get_template( 'single-product/product-image-slider.php' );
		} else {
			wc_get_template( 'single-product/product-image.php' );
		}
	}

	remove_action( 'woocommerce_checkout_order_review', 'woocommerce_checkout_payment', 20 );
	add_action( 'wooshop_checkout_payment_method', 'woocommerce_checkout_payment', 5 );

	remove_action( 'woocommerce_before_checkout_form', 'woocommerce_checkout_login_form', 10 );
	add_action( 'wooshop_checkout_login_form', 'woocommerce_checkout_login_form', 10 );

	// Shop/Catalog
	add_action( 'woocommerce_before_main_content', 'mts_product_category_ads' );
	function mts_product_category_ads() {
		if ( is_product_category() ) {
			global $wp_query;
			$term = $wp_query->get_queried_object();
			if ( is_active_sidebar('catalog-ads-'.$term->term_id) ) { ?>
				<div class="mts-image-widgets catalog-ad-widgets clearfix">
					<div class="container mts-images-container">
						<?php if ( !function_exists('dynamic_sidebar') || !dynamic_sidebar( 'catalog-ads-'.$term->term_id ) ) : ?><?php endif; ?>
					</div>
				</div>
			<?php } elseif ( is_active_sidebar('catalog-ads') ) { ?>
				<div class="mts-image-widgets catalog-ad-widgets clearfix">
					<div class="container mts-images-container">
						<?php if ( !function_exists('dynamic_sidebar') || !dynamic_sidebar( 'catalog-ads' ) ) : ?><?php endif; ?>
					</div>
				</div>
			<?php }
		} elseif ( is_shop() ) {
			if ( is_active_sidebar('catalog-ads') ) { ?>
				<div class="mts-image-widgets shop-ad-widgets clearfix">
					<div class="container mts-images-container">
						<?php if ( !function_exists('dynamic_sidebar') || !dynamic_sidebar( 'catalog-ads' ) ) : ?><?php endif; ?>
					</div>
				</div>
			<?php }
		}
	}

	add_filter( 'woocommerce_product_add_to_cart_text', 'mts_archive_add_to_cart_text' );
	function mts_archive_add_to_cart_text() {
			return '';
	}

	add_filter( 'woocommerce_pagination_args' , 'mts_override_pagination_args' );

	function mts_override_pagination_args( $args ) {
		$args['prev_text'] = __( 'Previous', 'wooshop' );
		$args['next_text'] = __( 'Next', 'wooshop' );
		return $args;
	}

	/*
	 * Size Chart
	 */
	add_action( 'init', 'mts_register_size_chart_post_types' );
	function mts_register_size_chart_post_types() {
		$labels = array(
			'name'				=> __( 'Size Charts', 'wooshop' ),
			'singular_name'		=> __( 'Size Chart', 'wooshop' ),
			'add_new'			=> __( 'Add Size Chart', 'wooshop' ),
			'add_new_item'		=> __( 'New Size Chart', 'wooshop' ),
			'edit_item'			=> __( 'Edit Size Chart', 'wooshop' ),
			'view_item'			=> __( 'View Size Chart', 'wooshop' ),
			'not_found'			=> __( 'Size Chart not found', 'wooshop' ),
			'not_found_in_trash'=> __( 'Size Chart not found in trash', 'wooshop' )
		);

		$args = array(
			'labels'				=> $labels,
			'public'				=> false,
			'show_ui'				=> true,
			'menu_position'			=> 10,
			'exclude_from_search'	=> true,
			'capability_type'		=> 'post',
			'map_meta_cap'			=> true,
			'hierarchical'			=> false,
			'rewrite'				=> false,
			'publicly_queryable'	=> false,
			'show_in_nav_menus'		=> false,
			'menu_icon'				=> 'dashicons-grid-view',
			'supports'				=> array( 'title' ),
		);

		register_post_type( 'mts_size_chart', $args );

		$labels2 = array(
			'name'					=> __( 'Size Chart Popups', 'wooshop' ),
			'singular_name'			=> __( 'Size Chart Popup', 'wooshop' ),
			'add_new'				=> __( 'Add Size Chart Popup', 'wooshop' ),
			'add_new_item'			=> __( 'New Size Chart Popup', 'wooshop' ),
			'edit_item'				=> __( 'Edit Size Chart Popup', 'wooshop' ),
			'view_item'				=> __( 'View Size Chart Popup', 'wooshop' ),
			'not_found'				=> __( 'Size Chart Popup not found', 'wooshop' ),
			'not_found_in_trash'	=> __( 'Size Chart Popup not found in trash', 'wooshop' )
		);

		$args2 = array(
			'labels'				=> $labels2,
			'public'				=> false,
			'show_ui'				=> true,
			'menu_position'			=> 10,
			'exclude_from_search'	=> true,
			'capability_type'		=> 'post',
			'map_meta_cap'			=> true,
			'hierarchical'			=> false,
			'rewrite'				=> false,
			'publicly_queryable'	=> false,
			'show_in_nav_menus'		=> false,
			'menu_icon'				=> 'dashicons-grid-view',
			'supports'				=> array( 'title', 'thumbnail' ),
		);

		register_post_type( 'mts_size_chart_popup', $args2 );
	}

	add_action( 'product_cat_add_form_fields', 'mts_product_cat_size_chart_popup_add_form_fields' );
	add_action( 'product_cat_edit_form_fields', 'mts_product_cat_size_chart_popup_edit_form_fields', 10, 2 );
	// Handle creating/editing/deleting of color attribute color
	add_action( 'created_term', 'mts_create_update_product_cat_size_chart_popup', 10, 3 );
	add_action( 'edited_term', 'mts_create_update_product_cat_size_chart_popup', 10, 3 );
	add_action( 'delete_term', 'mts_delete_product_cat_size_chart_popup', 10, 3 );

	function mts_product_cat_size_chart_popup_add_form_fields() {
		?>
		<div class="form-field">
			<label for="mts_size_chart_popup">
				<?php _e( 'Size chart popup: ', 'wooshop' ); ?>
			</label>
			<select id="mts_size_chart_popup" name="mts_size_chart_popup">
				<?php
				$options = mts_get_size_chart_popups_options_array();
				foreach ( $options as $id => $name ) {
					echo  '<option value="'.$id.'">'.$name.'</option>';
				}
				?>
			</select>
		</div>
		<?php
	}
	function mts_product_cat_size_chart_popup_edit_form_fields( $tag, $taxonomy ) {
		// clear value.
		$popup = '';
		// tag id
		$id = $tag->term_id;
		$opt_array = get_option('mts_size_chart_popups');
		if ( $opt_array && array_key_exists( $id, $opt_array ) ) {
			$popup = $opt_array[ $id ];
		}
		?>
		<tr class="form-field">
			<th scope="row" valign="top">
				<label for="mts_size_chart_popup"><?php _e( 'Size chart popup:', 'wooshop' ); ?></label>
			</th>
			<td>
				<select id="mts_size_chart_popup" name="mts_size_chart_popup">
					<?php
					$options = mts_get_size_chart_popups_options_array();
					foreach ( $options as $id => $name ) {
						$selected = $popup == $id ? ' selected="selected"': '';
						echo  '<option value="'.$id.'"'.$selected.'>'.$name.'</option>';
					}
					?>
				</select>
			</td>
		</tr>
		<?php
	}
	function mts_create_update_product_cat_size_chart_popup( $term_id, $tt_id, $taxonomy ) {
		$opt_array = get_option('mts_size_chart_popups');
		if ( isset( $_POST['mts_size_chart_popup'] ) ) {
			$opt_array[ $term_id ] = $_POST['mts_size_chart_popup'];
		}
		if ( isset( $opt_array ) ) {
			update_option( 'mts_size_chart_popups' , $opt_array );
		}
	}
	function mts_delete_product_cat_size_chart_popup( $term_id, $tt_id, $taxonomy ) {
		$opt_array = get_option('mts_size_chart_popups');
		if ( $opt_array && isset( $opt_array[ $term_id ] ) ) {
			unset( $opt_array[ $term_id ] );
			update_option('mts_size_chart_popups', $opt_array);
		}
	}

	add_action( 'wp', 'get_size_chart_popups' );
	function get_size_chart_popups() {
		global $mts_size_chart_popup;
		$mts_size_chart_popup = '';

		if ( is_product() ) {

			global $post;

			$disable = get_post_meta( $post->ID, '_mts_product_size_chart_popup_disable', true ) ? get_post_meta( $post->ID, '_mts_product_size_chart_popup_disable', true ) : 'no';

			if ( 'no' === $disable ) {

				if ( empty( $mts_size_chart_popup ) ) {
					// Check if product have popup assigned
					$mts_size_chart_popup = get_post_meta( $post->ID, '_mts_product_size_chart_popup', true ) ? get_post_meta( $post->ID, '_mts_product_size_chart_popup', true ) : '';
				}

				if ( empty( $mts_size_chart_popup ) ) {
					// Check if product category have popup assigned
					/*
					$term_list = wp_get_post_terms( $post->ID, 'product_cat', array("fields" => "ids") );
					$cat_popups = get_option( 'mts_size_chart_popups', array() );
					if ( !empty( $cat_popups ) && !empty( $term_list ) && !is_wp_error( $term_list ) ) {
						foreach ( $term_list as $term_id ) {
							if ( array_key_exists( $term_id, $cat_popups ) ) {
								$mts_size_chart_popup = $cat_popups[ $term_id ];
								break;
							}
						}
					}
					 */
					$cat = mts_get_deepest_product_cat();
					$cat_popups = get_option( 'mts_size_chart_popups', array() );
					if ( !empty( $cat_popups ) && !empty( $cat ) ) {
						if ( array_key_exists( $cat->term_id, $cat_popups ) ) {
							$mts_size_chart_popup = $cat_popups[ $cat->term_id ];
						}
					}

				}

				if ( empty( $mts_size_chart_popup ) ) {
					// global
					global $mts_options;
					$mts_size_chart_popup = isset( $mts_options['mts_global_size_chart_popup'] ) && !empty( $mts_options['mts_global_size_chart_popup'] ) ? $mts_options['mts_global_size_chart_popup'] : '';
				}
			}
		}
	}

	function mts_get_deepest_product_cat( $id = null ) {
		if ( ! $id ) {
			global $post;
			$id = $post->ID;
		}
		$categories = get_the_terms( $id, 'product_cat' );
		$cat = false;
		// wrapper to hide any errors from top level categories or products without category
		if ( $categories && ! is_wp_error( $categories ) ) {
			$firstcat = false;
		    // loop through each cat
			foreach ( $categories as $category ) {
				if ( ! $firstcat ) {
					$firstcat = $category;
				}
				// get the children (if any) of the current cat
				$children = get_categories( array( 'taxonomy' => 'product_cat', 'parent' => $category->term_id ) );

				if ( count($children) == 0 ) {
					// if no children, then echo the category name.
					$cat = $category;
					break;
				}
		    }
		    if ( ! $cat ) {
		    	$cat = $firstcat;
		    }
		}
		return $cat;
	}

	// Display Size Chart Popup
	add_action( 'woocommerce_single_product_summary', 'mts_size_chart_popup', 10 );
	function mts_size_chart_popup() {
		global $mts_size_chart_popup;
		if ( !empty( $mts_size_chart_popup ) && 'publish' === get_post_status( $mts_size_chart_popup ) ) {
			$default_settings = array(
				'link_title' => __('Size Chart', 'wooshop'),
				'charts' => '',
			);
			$settings = get_post_meta( $mts_size_chart_popup, '_chart_popup_settings', true ) ? get_post_meta( $mts_size_chart_popup, '_chart_popup_settings', true ) : $default_settings;
			echo '<a href="#mts-size-chart-popup-'.$mts_size_chart_popup.'" class="mts-size-chart-popup-link">'.$settings['link_title'].'<a>';
			echo mts_get_size_chart_popup_html( $mts_size_chart_popup, $settings );
		}
	}
	function mts_get_size_chart_popup_html( $id, $settings ) {
		$class = '';
		if ( !has_post_thumbnail( $id ) || empty( $settings['charts'] ) ) { $class = ' one-element'; }
		$output = '<div id="mts-size-chart-popup-'.$id.'" class="mts-size-chart-popup mfp-hide clearfix'.$class.'">';
			$output .= '<div class="mts-size-chart-popup-inner">';
				$output .= '<div class="mts-size-chart-popup-header">';
					$output .= '<h4 class="mts-size-chart-popup-title">';
						$output .= get_the_title( $id );
					$output .='</h4>';
				$output .= '</div>';
				$output .= '<div class="mts-size-chart-popup-content">';
					if ( has_post_thumbnail( $id ) ) {
						$output .= '<div class="mts-size-chart-popup-image">';
						$size = empty( $settings['charts'] ) ? 'wooshop-size-chart-full' : 'wooshop-size-chart';
							$output .= get_the_post_thumbnail( $id, $size );
						$output .= '</div>';
					}
					if ( !empty( $settings['charts'] ) ) {
						$output .= '<div class="mts-size-chart-popup-tables">';
							foreach ( $settings['charts'] as $chart_id ) {
								$output .= '<div class="mts-size-chart-popup-table">';
									$output .= '<h4 class="mts-size-chart-popup-table-title">';
										$output .= get_the_title( $chart_id );
									$output .='</h4>';
									$table_meta = get_post_meta( $chart_id, '_table_meta', true ) ? get_post_meta( $chart_id, '_table_meta', true ) : '[[""]]';
									$t= json_decode( $table_meta );
									$output .= '<div class="mts-product-table-responsive-container">';
										$output .= '<table class="mts-product-table">';
											$output .= '<thead>';
											$output .= '<tr>';
												foreach ( $t[ 0 ] as $col ):
													$output .= '<th>';
														$output .= $col;
													$output .= '</th>';
												endforeach;
											$output .= '</tr>';
											$output .= '</thead>';
											$output .= '<tbody>';
											foreach ( $t as $idx => $row ):
												if ( $idx == 0 )
													continue;
												$output .= '<tr>';
													foreach ( $row as $col ):
														$output .= '<td>';
															$output .= '<div class="mts-product-table-td-content">';
																$output .= str_replace( '"', '&quot;', $col );
															$output .= '</div>';
														$output .= '</td>';
													endforeach;
												$output .= '</tr>';
											endforeach;
											$output .= '</tbody>';
										$output .= '</table>';
									$output .= '</div>';
								$output .= '</div>';
							}
						$output .= '</div>';
					}
				$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';
		return $output;
	}
}

function mts_get_size_chart_popups_options_array() {
	$charts_query = array(
		'posts_per_page' => -1,
		'post_status' => array('publish'),
		'post_type' => 'mts_size_chart_popup',
		'order' => 'ASC',
		'orderby' => 'title',
		'suppress_filters' => false,
	);

	$size_chart_popups = array( '' => __('-- Select --', 'wooshop') );
	$charts = get_posts( $charts_query );
	foreach ( $charts as $chart ) {
		$size_chart_popups[ $chart->ID ] = $chart->post_title;
	}

	return $size_chart_popups;
}

function mts_get_size_charts_options_array() {
	$charts_query = array(
		'posts_per_page' => -1,
		'post_status' => array('publish'),
		'post_type' => 'mts_size_chart',
		'order' => 'ASC',
		'orderby' => 'title',
		'suppress_filters' => false,
	);

	$size_chart_popups = array();
	$charts = get_posts( $charts_query );
	foreach ( $charts as $chart ) {
		$size_chart_popups[ $chart->ID ] = $chart->post_title;
	}

	return $size_chart_popups;
}

/**
 * Add <!-- next-page --> button to tinymce.
 *
 * @param $mce_buttons
 *
 * @return array
 */
function mts_wysiwyg_editor( $mce_buttons ) {
   $pos = array_search( 'wp_more', $mce_buttons, true );
   if ( $pos !== false ) {
	   $tmp_buttons = array_slice( $mce_buttons, 0, $pos+1 );
	   $tmp_buttons[] = 'wp_page';
	   $mce_buttons = array_merge( $tmp_buttons, array_slice( $mce_buttons, $pos+1 ));
   }
   return $mce_buttons;
}
add_filter( 'mce_buttons', 'mts_wysiwyg_editor' );

/**
 * Get Post header animation.
 *
 * @return string
 */
function mts_get_post_header_effect() {
	$postheader_effect = get_post_meta( get_the_ID(), '_mts_postheader', true );

	return $postheader_effect;
}

/**
 * Add Custom Gravatar Support.
 *
 * @param $avatar_defaults
 *
 * @return mixed
 */
function mts_custom_gravatar( $avatar_defaults ) {
	$mts_avatar = get_template_directory_uri() . '/images/gravatar.png';
	$avatar_defaults[$mts_avatar] = __( 'Custom Gravatar ( /images/gravatar.png )', 'wooshop' );
	return $avatar_defaults;
}
add_filter( 'avatar_defaults', 'mts_custom_gravatar' );

/**
 * Add `.primary-navigation` the WP Mega Menu's
 * @param $selector
 *
 * @return string
 */
function mts_megamenu_parent_element( $selector ) {
	return '.navigation-wrap';
}
add_filter( 'wpmm_container_selector', 'mts_megamenu_parent_element' );

/**
 * Change the image size of WP Mega Menu's thumbnails.
 *
 * @param $thumbnail_html
 * @param $post_id
 *
 * @return string
 */
if( ! function_exists( 'mts_megamenu_thumbnails' ) ) {
	function mts_megamenu_thumbnails( $thumbnail_html, $post_id ) {
		$thumbnail_html = '<div class="wpmm-thumbnail">';
		$thumbnail_html .= '<a title="'.get_the_title( $post_id ).'" href="'.get_permalink( $post_id ).'">';
		if(has_post_thumbnail($post_id)):
			$thumbnail_html .= get_the_post_thumbnail($post_id, 'wooshop-widgetfull', array('title' => ''));
		else:
			$thumbnail_html .= '<img src="'.get_template_directory_uri().'/images/nothumb-wooshop-widgetfull.png" alt="'.__('No Preview', 'wooshop').'"  class="wp-post-image" />';
		endif;
		$thumbnail_html .= '</a>';

		// WP Review
		$thumbnail_html .= (function_exists('wp_review_show_total') ? wp_review_show_total(false) : '');

		$thumbnail_html .= '</div>';

		return $thumbnail_html;
	}
}	
add_filter( 'wpmm_thumbnail_html', 'mts_megamenu_thumbnails', 10, 2 );

/*-----------------------------------------------------------------------------------*/
/*  WP Review Support
/*-----------------------------------------------------------------------------------*/

/**
 * Set default colors for new reviews.
 *
 * @param $colors
 *
 * @return array
 */
function mts_new_default_review_colors( $colors ) {
	$colors = array(
		'color' => '#FFCA00',
		'fontcolor' => '#fff',
		'bgcolor1' => '#151515',
		'bgcolor2' => '#151515',
		'bordercolor' => '#151515'
	);
  return $colors;
}
add_filter( 'wp_review_default_colors', 'mts_new_default_review_colors' );

/**
 * Set default location for new reviews.
 *
 * @param $position
 *
 * @return string
 */
function mts_new_default_review_location( $position ) {
  $position = 'top';
  return $position;
}
add_filter( 'wp_review_default_location', 'mts_new_default_review_location' );

/**
 * Thumbnail Upscale
 *  Enables upscaling of thumbnails for small media attachments,
 *  to make sure it fits into it's supposed location.
 *  Cannot be used in conjunction with Retina Support.
 *
 * @param $default
 * @param $orig_w
 * @param $orig_h
 * @param $new_w
 * @param $new_h
 * @param $crop
 *
 * @return array|null
 */
function mts_image_crop_dimensions( $default, $orig_w, $orig_h, $new_w, $new_h, $crop ) {

	if( !$crop || ($orig_w == 512 && $orig_h == 512) )
		return null; // let the wordpress default function handle this

	$aspect_ratio = $orig_w / $orig_h;
	$size_ratio = max( $new_w / $orig_w, $new_h / $orig_h );

	$crop_w = round( $new_w / $size_ratio );
	$crop_h = round( $new_h / $size_ratio );

	$s_x = floor( ( $orig_w - $crop_w ) / 2 );
	$s_y = floor( ( $orig_h - $crop_h ) / 2 );

	return array( 0, 0, ( int ) $s_x, ( int ) $s_y, ( int ) $new_w, ( int ) $new_h, ( int ) $crop_w, ( int ) $crop_h );
}
add_filter( 'image_resize_dimensions', 'mts_image_crop_dimensions', 10, 6 );


/**
 * Post view count
 * AJAX is used to support caching plugins - it is possible to disable with filter
 * It is also possible to exclude admins with another filter
 */

/**
 * Append JS to content for AJAX call on single.
 *
 * @param $content
 *
 * @return string
 */
function mts_view_count_js( $content ) {
	$id = get_the_ID();
	$use_ajax = apply_filters( 'mts_view_count_cache_support', true );

	$exclude_admins = apply_filters( 'mts_view_count_exclude_admins', false ); // pass in true or a user capability
	if ($exclude_admins === true) {
		$exclude_admins = 'edit_posts';
	}
	if ($exclude_admins && current_user_can( $exclude_admins )) {
		return $content; // do not count post views here
	}

	if (is_single()) {
		if ($use_ajax) {
			// enqueue jquery
			wp_enqueue_script( 'jquery' );

			$url = admin_url( 'admin-ajax.php' );
			$content .= "
			<script type=\"text/javascript\">
			jQuery(document).ready(function($) {
				$.post('".esc_js($url)."', {action: 'mts_view_count', id: '".esc_js($id)."'});
			});
			</script>";
		}

		if (!$use_ajax) {
			mts_update_view_count($id);
		}
	}

	return $content;
}
//add_filter('the_content', 'mts_view_count_js');

/**
 * Call mts_update_view_count on AJAX.
 */
function mts_ajax_mts_view_count() {
	// do count
	$post_id = absint( $_POST['id'] );
	mts_update_view_count( $post_id );
	exit();
}
add_action('wp_ajax_mts_view_count', 'mts_ajax_mts_view_count');
add_action('wp_ajax_nopriv_mts_view_count','mts_ajax_mts_view_count');

/**
 * Update the view count of a post.
 *
 * @param $post_id
 */
function mts_update_view_count( $post_id ) {
	$count = get_post_meta( $post_id, '_mts_view_count', true );
	update_post_meta( $post_id, '_mts_view_count', ++$count );

	do_action( 'mts_view_count_after_update', $post_id, $count );

	return $count;
}

/**
 * Convert color format from HEX to HSL.
 * @param $color
 *
 * @return array
 */
function mts_hex_to_hsl( $color ){

	// Sanity check
	$color = mts_check_hex_color($color);

	// Convert HEX to DEC
	$R = hexdec($color[0].$color[1]);
	$G = hexdec($color[2].$color[3]);
	$B = hexdec($color[4].$color[5]);

	$HSL = array();

	$var_R = ($R / 255);
	$var_G = ($G / 255);
	$var_B = ($B / 255);

	$var_Min = min($var_R, $var_G, $var_B);
	$var_Max = max($var_R, $var_G, $var_B);
	$del_Max = $var_Max - $var_Min;

	$L = ($var_Max + $var_Min)/2;

	if ($del_Max == 0) {
		$H = 0;
		$S = 0;
	} else {
		if ( $L < 0.5 ) $S = $del_Max / ( $var_Max + $var_Min );
		else			$S = $del_Max / ( 2 - $var_Max - $var_Min );

		$del_R = ( ( ( $var_Max - $var_R ) / 6 ) + ( $del_Max / 2 ) ) / $del_Max;
		$del_G = ( ( ( $var_Max - $var_G ) / 6 ) + ( $del_Max / 2 ) ) / $del_Max;
		$del_B = ( ( ( $var_Max - $var_B ) / 6 ) + ( $del_Max / 2 ) ) / $del_Max;

		if	  ($var_R == $var_Max) $H = $del_B - $del_G;
		else if ($var_G == $var_Max) $H = ( 1 / 3 ) + $del_R - $del_B;
		else if ($var_B == $var_Max) $H = ( 2 / 3 ) + $del_G - $del_R;

		if ($H<0) $H++;
		if ($H>1) $H--;
	}

	$HSL['H'] = ($H*360);
	$HSL['S'] = $S;
	$HSL['L'] = $L;

	return $HSL;
}

/**
 * Convert color format from HSL to HEX.
 *
 * @param array $hsl
 *
 * @return string
 */
function mts_hsl_to_hex( $hsl = array() ){

	list($H,$S,$L) = array( $hsl['H']/360,$hsl['S'],$hsl['L'] );

	if( $S == 0 ) {
		$r = $L * 255;
		$g = $L * 255;
		$b = $L * 255;
	} else {

		if($L<0.5) {
			$var_2 = $L*(1+$S);
		} else {
			$var_2 = ($L+$S) - ($S*$L);
		}

		$var_1 = 2 * $L - $var_2;

		$r = round(255 * mts_huetorgb( $var_1, $var_2, $H + (1/3) ));
		$g = round(255 * mts_huetorgb( $var_1, $var_2, $H ));
		$b = round(255 * mts_huetorgb( $var_1, $var_2, $H - (1/3) ));
	}

	// Convert to hex
	$r = dechex($r);
	$g = dechex($g);
	$b = dechex($b);

	// Make sure we get 2 digits for decimals
	$r = (strlen("".$r)===1) ? "0".$r:$r;
	$g = (strlen("".$g)===1) ? "0".$g:$g;
	$b = (strlen("".$b)===1) ? "0".$b:$b;

	return $r.$g.$b;
}

/**
 * Convert color format from Hue to RGB.
 *
 * @param $v1
 * @param $v2
 * @param $vH
 *
 * @return mixed
 */
function mts_huetorgb( $v1,$v2,$vH ) {
	if( $vH < 0 ) {
		$vH += 1;
	}

	if( $vH > 1 ) {
		$vH -= 1;
	}

	if( (6*$vH) < 1 ) {
		   return ($v1 + ($v2 - $v1) * 6 * $vH);
	}

	if( (2*$vH) < 1 ) {
		return $v2;
	}

	if( (3*$vH) < 2 ) {
		return ($v1 + ($v2-$v1) * ( (2/3)-$vH ) * 6);
	}

	return $v1;

}

/**
 * Get the 6-digit hex color.
 *
 * @param $hex
 *
 * @return mixed|string
 */
function mts_check_hex_color( $hex ) {
	// Strip # sign is present
	$color = str_replace("#", "", $hex);

	// Make sure it's 6 digits
	if( strlen($color) == 3 ) {
		$color = $color[0].$color[0].$color[1].$color[1].$color[2].$color[2];
	}

	return $color;
}

/**
 * Check if color is considered light or not.
 * @param $color
 *
 * @return bool
 */
function mts_is_light_color( $color ){

	$color = mts_check_hex_color( $color );

	// Calculate straight from rbg
	$r = hexdec($color[0].$color[1]);
	$g = hexdec($color[2].$color[3]);
	$b = hexdec($color[4].$color[5]);

	return ( ( $r*299 + $g*587 + $b*114 )/1000 > 130 );
}

/**
 * Darken color by given amount in %.
 *
 * @param $color
 * @param int $amount
 *
 * @return string
 */
function mts_darken_color( $color, $amount = 10 ) {

	$hsl = mts_hex_to_hsl( $color );

	// Darken
	$hsl['L'] = ( $hsl['L'] * 100 ) - $amount;
	$hsl['L'] = ( $hsl['L'] < 0 ) ? 0 : $hsl['L']/100;

	// Return as HEX
	return mts_hsl_to_hex($hsl);
}

/**
 * Lighten color by given amount in %.
 *
 * @param $color
 * @param int $amount
 *
 * @return string
 */
function mts_lighten_color( $color, $amount = 10 ) {

	$hsl = mts_hex_to_hsl( $color );

	// Lighten
	$hsl['L'] = ( $hsl['L'] * 100 ) + $amount;
	$hsl['L'] = ( $hsl['L'] > 100 ) ? 1 : $hsl['L']/100;

	// Return as HEX
	return mts_hsl_to_hex($hsl);
}

/**
 * Used to create rgb from hexa decimal value
 * @return string
 */
function mts_convert_hex_to_rgb($hex){
	list($r, $g, $b) = sscanf($hex, "#%02x%02x%02x");
	return "$r, $g, $b";
}

/**
 * Generate css from background theme option.
 *
 * @param $option_id
 *
 * @return string|void
 */
if( ! function_exists( 'mts_get_background_styles' ) ) {
	function mts_get_background_styles( $option_id ) {

		$mts_options = get_option( MTS_THEME_NAME );

		if ( ! isset( $mts_options[ $option_id ]) ) {
			return;
		}

		$background_option = $mts_options[ $option_id ];
		$output = '';
		$background_image_type = isset( $background_option['use'] ) ? $background_option['use'] : '';

		if ( isset( $background_option['color'] ) && !empty( $background_option['color'] ) && 'gradient' !== $background_image_type ) {
			$output .= 'background-color:'.$background_option['color'].';';
		}

		if ( !empty( $background_image_type ) ) {

			if ( 'upload' == $background_image_type ) {

				if ( isset( $background_option['image_upload'] ) && !empty( $background_option['image_upload'] ) ) {
					$output .= 'background-image:url('.$background_option['image_upload'].');';
				}
				if ( isset( $background_option['repeat'] ) && !empty( $background_option['repeat'] ) ) {
					$output .= 'background-repeat:'.$background_option['repeat'].';';
				}
				if ( isset( $background_option['attachment'] ) && !empty( $background_option['attachment'] ) ) {
					$output .= 'background-attachment:'.$background_option['attachment'].';';
				}
				if ( isset( $background_option['position'] ) && !empty( $background_option['position'] ) ) {
					$output .= 'background-position:'.$background_option['position'].';';
				}
				if ( isset( $background_option['size'] ) && !empty( $background_option['size'] ) ) {
					$output .= 'background-size:'.$background_option['size'].';';
				}

			} else if ( 'gradient' == $background_image_type ) {

				$from	  = $background_option['gradient']['from'];
				$to		= $background_option['gradient']['to'];
				$direction = $background_option['gradient']['direction'];

				if ( !empty( $from ) && !empty( $to ) ) {

					$output .= 'background: '.$background_option['color'].';';

					if ( 'horizontal' == $direction ) {

						$output .= 'background: -moz-linear-gradient(left, '.$from.' 0%, '.$to.' 100%);';
						$output .= 'background: -webkit-gradient(linear, left top, right top, color-stop(0%,'.$from.'), color-stop(100%,'.$to.'));';
						$output .= 'background: -webkit-linear-gradient(left, '.$from.' 0%,'.$to.' 100%);';
						$output .= 'background: -o-linear-gradient(left, '.$from.' 0%,'.$to.' 100%);';
						$output .= 'background: -ms-linear-gradient(left, '.$from.' 0%,'.$to.' 100%);';
						$output .= 'background: linear-gradient(to right, '.$from.' 0%,'.$to.' 100%);';
						$output .= "filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='".$from."', endColorstr='".$to."',GradientType=1 );";

					} else {

						$output .= 'background: -moz-linear-gradient(top, '.$from.' 0%, '.$to.' 100%);';
						$output .= 'background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,'.$from.'), color-stop(100%,'.$to.'));';
						$output .= 'background: -webkit-linear-gradient(top, '.$from.' 0%,'.$to.' 100%);';
						$output .= 'background: -o-linear-gradient(top, '.$from.' 0%,'.$to.' 100%);';
						$output .= 'background: -ms-linear-gradient(top, '.$from.' 0%,'.$to.' 100%);';
						$output .= 'background: linear-gradient(to bottom, '.$from.' 0%,'.$to.' 100%);';
						$output .= "filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='".$from."', endColorstr='".$to."',GradientType=0 );";
					}
				}

			} else if ( 'pattern' == $background_image_type && ($background_option['image_pattern'] == 'blackimg' || $background_option['image_pattern'] == 'whiteimg' || $background_option['image_pattern'] == 'lightimg') ) {

				$output .= 'background-image:url('.get_template_directory_uri().'/images/'.$background_option['image_pattern'].'.jpg'.');';

			} else if ( 'pattern' == $background_image_type ) {

				$output .= 'background-image:url('.get_template_directory_uri().'/images/'.$background_option['image_pattern'].'.png'.');';
			}
		}

		return $output;
	}
}
/**
 * Add link to theme options panel inside admin bar
 */
function mts_admin_bar_link() {
	/** @var WP_Admin_bar $wp_admin_bar */
	global $wp_admin_bar;

	if( current_user_can( 'edit_theme_options' ) ) {
		$wp_admin_bar->add_menu( array(
			'id' => 'mts-theme-options',
			'title' => __( 'Theme Options', 'wooshop' ),
			'href' => admin_url( 'themes.php?page=theme_options' )
		) );
	}
}
add_action( 'admin_bar_menu', 'mts_admin_bar_link', 65 );


/**
 * Retrieves the attachment ID from the file URL
 *
 * @param $image_url
 *
 * @return string
 */
if( ! function_exists( 'mts_get_image_id_from_url' ) ) {
	function mts_get_image_id_from_url( $image_url ) {
		if ( is_numeric( $image_url ) ) return $image_url;
		global $wpdb;
		$attachment = $wpdb->get_col( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE guid='%s';", $image_url ) );
		if ( isset( $attachment[0] ) ) {
			return $attachment[0];
		} else {
			return false;
		}
	}
}

/**
 * Remove new line tags from string
 *
 * @param $text
 *
 * @return string
 */
function mts_escape_text_tags( $text ) {
	return (string) str_replace( array( "\r", "\n" ), '', strip_tags( $text ) );
}

/**
 * Remove new line tags from string
 *
 * @return string
 */
if( ! function_exists( 'mts_single_post_schema' ) ) {
	function mts_single_post_schema() {

		if ( is_singular( 'post' ) ) {

			global $post, $mts_options;

			if ( has_post_thumbnail( $post->ID ) && !empty( $mts_options['mts_logo'] ) ) {

				$logo_id = mts_get_image_id_from_url( $mts_options['mts_logo'] );

				if ( $logo_id ) {

					$images  = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
					$logo	= wp_get_attachment_image_src( $logo_id, 'full' );
					$excerpt = mts_escape_text_tags( $post->post_excerpt );
					$content = $excerpt === "" ? mb_substr( mts_escape_text_tags( $post->post_content ), 0, 110 ) : $excerpt;

					$args = array(
						"@context" => "http://schema.org",
						"@type"	=> "BlogPosting",
						"mainEntityOfPage" => array(
							"@type" => "WebPage",
							"@id"   => get_permalink( $post->ID )
						),
						"headline" => ( function_exists( '_wp_render_title_tag' ) ? wp_get_document_title() : wp_title( '', false, 'right' ) ),
						"image"	=> array(
							"@type"  => "ImageObject",
							"url"	 => $images[0],
							"width"  => $images[1],
							"height" => $images[2]
						),
						"datePublished" => get_the_time( DATE_ISO8601, $post->ID ),
						"dateModified"  => get_post_modified_time(  DATE_ISO8601, __return_false(), $post->ID ),
						"author" => array(
							"@type" => "Person",
							"name"  => mts_escape_text_tags( get_the_author_meta( 'display_name', $post->post_author ) )
						),
						"publisher" => array(
							"@type" => "Organization",
							"name"  => get_bloginfo( 'name' ),
							"logo"  => array(
								"@type"  => "ImageObject",
								"url"	 => $logo[0],
								"width"  => $logo[1],
								"height" => $logo[2]
							)
						),
						"description" => ( class_exists('WPSEO_Meta') ? WPSEO_Meta::get_value( 'metadesc' ) : $content )
					);

					echo '<script type="application/ld+json">' , PHP_EOL;
					echo wp_json_encode( $args, JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT ) , PHP_EOL;
					echo '</script>' , PHP_EOL;
				}
			}
		}
	}
}	
add_action( 'wp_head', 'mts_single_post_schema' );

if ( ! empty( $mts_options['mts_async_js'] ) ) {
	function mts_js_async_attr($tag){

		if (is_admin())
			return $tag;

		$async_files = apply_filters( 'mts_js_async_files', array(
			get_template_directory_uri() . '/js/ajax.js',
			get_template_directory_uri() . '/js/contact.js',
			get_template_directory_uri() . '/js/customscript.js',
			get_template_directory_uri() . '/js/jquery.magnific-popup.min.js',
			get_template_directory_uri() . '/js/layzr.min.js',
			get_template_directory_uri() . '/js/owl.carousel.min.js',
			get_template_directory_uri() . '/js/parallax.js',
			get_template_directory_uri() . '/js/sticky.js',
			get_template_directory_uri() . '/js/zoomout.js',
		 ) );

		$add_async = false;
		foreach ($async_files as $file) {
			if (strpos($tag, $file) !== false) {
				$add_async = true;
				break;
			}
		}

		if ($add_async)
			$tag = str_replace( ' src', ' async="async" src', $tag );

		return $tag;
	}
	add_filter( 'script_loader_tag', 'mts_js_async_attr', 10 );
}

if ( ! empty( $mts_options['mts_remove_ver_params'] ) ) {
	function mts_remove_script_version( $src ){

		if ( is_admin() )
			return $src;

		$parts = explode( '?ver', $src );
		return $parts[0];
	}
	add_filter( 'script_loader_src', 'mts_remove_script_version', 15, 1 );
	add_filter( 'style_loader_src', 'mts_remove_script_version', 15, 1 );
}

/*
 * Check if Latest Posts are being displayed on homepage and set posts_per_page accordingly
 */
function mts_home_posts_per_page($query) {
	global $mts_options;

	if ( ! $query->is_home() || ! $query->is_main_query() )
		return;

	$set_posts_per_page = 0;
	if ( ! empty( $mts_options['mts_featured_categories'] ) ) {
		foreach ( $mts_options['mts_featured_categories'] as $section ) {
			if ( $section['mts_featured_category'] == 'latest' ) {
				$set_posts_per_page = $section['mts_featured_category_postsnum'];
				break;
			}
		}
	}
	if ( ! empty( $set_posts_per_page ) ) {
		$query->set( 'posts_per_page', $set_posts_per_page );
	}
}
//add_action( 'pre_get_posts', 'mts_home_posts_per_page' );

// Map images and categories in group field after demo content import
add_filter( 'mts_correct_single_import_option', 'mts_map_import_options_data', 10, 3 );
function mts_map_import_options_data( $item, $key, $data ) {

    if ( !in_array( $key, array( 'mts_accepted_payment_method_icons', 'mts_custom_slider', 'mts_quare_banner_images', 'mts_blog_custom_slider', 'mts_featured_categories' ) ) ) return $item;

    $new_item = $item;

    if ( 'mts_accepted_payment_method_icons' === $key ) {

        foreach( $item as $i => $image ) {

            $id = $image['mts_accepted_payment_method_image'];

            if ( is_numeric( $id ) ) {

                if ( array_key_exists( $id, $data['posts'] ) ) {

                    $new_item[ $i ]['mts_accepted_payment_method_image'] = $data['posts'][ $id ];
                }

            } else {

                if ( array_key_exists( $id, $data['image_urls'] ) ) {

                    $new_item[ $i ]['mts_accepted_payment_method_image'] = $data['image_urls'][ $id ];
                }
            }
        }

    } else if ( 'mts_custom_slider' === $key ) {

        foreach( $item as $i => $image ) {

            $id = $image['mts_custom_slider_image'];

            if ( is_numeric( $id ) ) {

                if ( array_key_exists( $id, $data['posts'] ) ) {

                    $new_item[ $i ]['mts_custom_slider_image'] = $data['posts'][ $id ];
                }

            } else {

                if ( array_key_exists( $id, $data['image_urls'] ) ) {

                    $new_item[ $i ]['mts_custom_slider_image'] = $data['image_urls'][ $id ];
                }
            }
        }

    } else if ( 'mts_quare_banner_images' === $key ) {

        foreach( $item as $i => $image ) {

            $id = $image['mts_square_banner_image'];

            if ( is_numeric( $id ) ) {

                if ( array_key_exists( $id, $data['posts'] ) ) {

                    $new_item[ $i ]['mts_square_banner_image'] = $data['posts'][ $id ];
                }

            } else {

                if ( array_key_exists( $id, $data['image_urls'] ) ) {

                    $new_item[ $i ]['mts_square_banner_image'] = $data['image_urls'][ $id ];
                }
            }
        }

    } else if ( 'mts_blog_custom_slider' === $key ) {

        foreach( $item as $i => $image ) {

            $id = $image['mts_blog_custom_slider_image'];

            if ( is_numeric( $id ) ) {

                if ( array_key_exists( $id, $data['posts'] ) ) {

                    $new_item[ $i ]['mts_blog_custom_slider_image'] = $data['posts'][ $id ];
                }

            } else {

                if ( array_key_exists( $id, $data['image_urls'] ) ) {

                    $new_item[ $i ]['mts_blog_custom_slider_image'] = $data['image_urls'][ $id ];
                }
            }
        }

    } else { // mts_featured_categories

        foreach( $item as $i => $category ) {

            $cat_id = $category['mts_featured_category'];

            if ( is_numeric( $cat_id ) && array_key_exists( $cat_id, $data['terms']['category'] ) ) {

                $new_item[ $i ]['mts_featured_category'] = $data['terms']['category'][ $cat_id ];
            }
        }
    }

    return $new_item;
}
